/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @version $Id: IncomesGrid.js 15897 2013-05-21 09:02:45Z mschering $
 * @copyright Copyright Intermesh
 * @author Merijn Schering <mschering@intermesh.nl>
 */



GO.projects.IncomesGrid = function(config){
	if(!config)
	{
		config = {};
	}

	this.summary = new Ext.grid.GridSummary();

	config.plugins = this.summary;
	
	config.layout='fit';
	config.autoScroll=true;
	config.split=true;
	//config.disabled=true;
	var fields ={
		fields:['id','project_id','type','amount','converted_amount','date','orig_currency','orig_exchange','description'],
		columns:[	{
			header: GO.lang.strType,
			dataIndex: 'type',
			editor: new Ext.grid.GridEditor(new GO.projects.SelectIncomeType(), {
				revertInvalid: false,
				getValue:function() {
					return this.field.getRawValue();
				}
			}),
			summaryRenderer:function(){
				return GO.lang.total;
			}
		},{
			
			header: GO.lang.strDescription,
			dataIndex: 'description',
			editor: new Ext.grid.GridEditor(new Ext.form.TextArea())
		}]
	}

	if(GO.currencies){
		fields.columns.push({
			header: GO.currencies.lang.currency,
			dataIndex: 'orig_currency',
			editor: this.selectCurrency = new GO.currencies.SelectCurrency({
				allowBlank: false
			})
		});
	}
	fields.columns.push({
			header: GO.projects.lang.amount,
			dataIndex: 'amount',
			summaryType: 'sum',
			summaryRenderer:function(v){
				if(GO.currencies){
					return '&nbsp;';
				}else
				{
					return v;
				}
			},
			editor: new GO.form.NumberField({
				allowBlank: false
			}),
			align:'right',
			renderer:function(v){
				var number = GO.util.unlocalizeNumber(v);
				return GO.util.numberFormat(number);
			}
		});

	if(GO.currencies){
		fields.columns.push({
				header: GO.projects.lang.amount+' ('+GO.currencies.defaultCurrency+')',
				dataIndex: 'converted_amount',
				summaryType: 'sum',
				summaryRenderer:function(v){
					return GO.currencies.defaultCurrency+'&nbsp;'+v;
				},
				align:'right',
				renderer:function(v){
					var number = GO.util.unlocalizeNumber(v);
					return GO.util.numberFormat(number);
				}
			});
	}

	fields.columns.push({
			header: GO.lang.strDate,
			dataIndex: 'date',
			editor: new Ext.form.DateField({
				format:GO.settings.date_format
			}),

			renderer: function(value){
				return typeof(value.dateFormat)=='undefined' ? value : value.dateFormat(GO.settings.date_format);
			},
			summaryRenderer:function(){
				return '&nbsp;';
			}
		});

		
	config.store = new GO.data.JsonStore({
		url: GO.url('projects/income/store'),
		baseParams: {
//			task: 'incomes'
		},
		root: 'results',
		id: 'id',
		totalProperty:'total',
		fields: fields.fields,
		remoteSort: true
	});

	config.bbar = new Ext.PagingToolbar({
		cls: 'go-paging-tb',
		store: config.store,
		pageSize: parseInt(GO.settings['max_rows_list']),
		displayInfo: true,
		displayMsg: GO.lang['displayingItems'],
		emptyMsg: GO.lang['strNoItems']
	});

	var columnModel =  new Ext.grid.ColumnModel({
		defaults:{
			sortable:true
		},
		columns:fields.columns
	});
	
	config.cm=columnModel;
	config.view=new Ext.grid.GridView({
		autoFill: true,
		forceFit: true,
		emptyText: GO.lang['strNoItems']
	});
	config.sm=new Ext.grid.RowSelectionModel();
	config.loadMask=true;

	config.clicksToEdit=1;


	var Income = Ext.data.Record.create([
	// the "name" below matches the tag name to read, except "availDate"
	// which is mapped to the tag "availability"
	{
		name: 'id',
		type: 'int'
	},

	{
		name: 'project_id',
		type: 'int'
	},{
		name: 'description',
		type: 'string'
	},

	{
		name: 'type',
		type:'string'
	},{
		name: 'converted_amount',
		type: 'string'
	},
	{
		name: 'amount',
		type: 'string'
	},             // automatic date conversions

	{
		name: 'date',
		mapping: 'date',
		type: 'date',
		dateFormat: GO.settings.date_format
	}
	]);


	config.tbar=[{
		iconCls: 'btn-add',
		text: GO.lang['cmdAdd'],
		cls: 'x-btn-text-icon',
		handler: function(){
			var e = new Income({
				id: '0',
				project_id: this.store.baseParams.project_id,
				amount: GO.util.numberFormat("0"),
				date: (new Date()).clearTime()
			});
			this.stopEditing();
			this.store.insert(0, e);
			this.startEditing(0, 0);
		},
		scope: this
	},{
		iconCls: 'btn-delete',
		text: GO.lang['cmdDelete'],
		cls: 'x-btn-text-icon',
		handler: function(){
			var selectedRows = this.selModel.getSelections();
			for(var i=0;i<selectedRows.length;i++)
			{
				selectedRows[i].commit();
				this.store.remove(selectedRows[i]);
			}
		},
		scope: this
	}];
	GO.projects.IncomesGrid.superclass.constructor.call(this, config);

};
Ext.extend(GO.projects.IncomesGrid, Ext.grid.EditorGridPanel,{
	setProjectId : function(project_id, noreload){
		this.project_id=this.store.baseParams.project_id=project_id;

		if(!noreload)
		{
			this.store.loaded=project_id==0;
			this.store.removeAll();
			if(this.summary.view.summary)
				this.summary.view.summary.update('');
		}
	},
	afterRender : function(){

		this.on('afteredit', function(e){
			if(e.field=='orig_currency'){
				var r = this.selectCurrency.store.getById(e.value)
				if(r){
					e.record.set('orig_exchange', GO.util.unlocalizeNumber(r.get('value')));
				}
			}
		}, this);

		if(this.store.baseParams.project_id){
			this.store.load();
		}

		GO.projects.IncomesGrid.superclass.afterRender.call(this);
	},
	onShow : function(){
		if(!this.store.loaded && this.store.baseParams.project_id){
			this.store.load();
		}
		GO.projects.IncomesGrid.superclass.onShow.call(this);
	},
	getGridData : function(){

		var data = {};

		for (var i = 0; i < this.store.data.items.length;  i++)
		{
			var r = this.store.data.items[i].data;

			data[i]={};

			for(var key in r)
			{
				data[i][key]=r[key];
			}
		}

		return data;
	},
	setIds : function(ids)
	{
		for(var index in ids)
		{
			if(index!="remove")
			{
				this.store.getAt(index).set('id', ids[index]);
			}
		}
	}
});
