/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @copyright Copyright Intermesh
 * @version $Id: ProjectDialog.js 16399 2013-07-23 13:55:30Z mschering $
 * @author Merijn Schering <mschering@intermesh.nl>
 */

 
GO.projects.ProjectDialog = function(config){
	if(!config)
	{
		config={};
	}

	config.goDialogId='project';

	this.buildForm();
	
	var focusName = function(){
		this.nameField.focus();		
	};

	config.id='pm-project-dialog';
	config.collapsible=true;
	config.maximizable=true;
	config.layout='fit';
	config.modal=false;
	config.resizable=true;
	config.width=750;
	config.height=500;
	config.closeAction='hide';
	config.title= GO.projects.lang.project;					
	config.items= this.formPanel;
	config.focus= focusName.createDelegate(this);
	config.buttons=[{
		text: GO.lang['cmdOk'],
		handler: function(){
			this.submitForm(true);
		},
		scope: this
	},{
		text: GO.lang['cmdApply'],
		handler: function(){
			this.submitForm();
		},
		scope:this
	},{
		text: GO.lang['cmdClose'],
		handler: function(){
			this.hide();
		},
		scope:this
	}
	];

	
	GO.projects.ProjectDialog.superclass.constructor.call(this, config);
	
	
	this.addEvents({
		'save' : true
	});
}

Ext.extend(GO.projects.ProjectDialog, GO.Window,{

	init : function(){
				
	},

	show : function (config) {

		if(!config)
		{
			config={};
		}

		if(!this.rendered)
			this.render(Ext.getBody());
		
		if(!this.inititalized){

			
			GO.request({
				url: 'core/multiRequest',
				maskEl:this.getEl(),
				params:{
					requests:Ext.encode({
						templates:{r:'projects/template/store'},
						types:{r:'projects/type/store'},
						statuses:{r:'projects/status/store'}
					})
				},
				success: function(options, response, result)
				{
					GO.projects.templatesStore.loadData(result.templates);
					GO.projects.typesStore.loadData(result.types);
					GO.projects.statusesStore.loadData(result.statuses);

					this.inititalized=true;

					if(GO.util.empty(this.selectType.getValue()))
						this.selectType.selectFirst();

					this.show(config);
				},
				scope:this
			});
			return false;
		}


		//this.formPanel.baseParams.template_id=0;

		if(!config.project_id)
		{
			config.project_id=0;

			if(typeof(config.template_id) == "undefined")
			{
				if(!this.selectTemplateWindow){
					this.selectTemplateWindow =new GO.projects.SelectTemplateWindow();
				}
				this.selectTemplateWindow.show(config);
				return false;
			}else
			{
				if(!GO.settings.modules.projects.write_permission)
					this.formPanel.baseParams.template_id=config.template_id;

				config.values = config.values || {};
				config.values.template_id=config.template_id;
				if(GO.projects.useNameTemplate == true || GO.projects.useNameTemplate == 1)
				{
					if(!config.values.name && GO.projects.nameTemplate!='')
						config.values.name=GO.projects.nameTemplate+' ';
				}
			}
		}

		this.formPanel.form.reset();
		this.selectType.setDisabled(!GO.settings.modules.projects.write_permission);
		this.templateSelect.setDisabled(!GO.settings.modules.projects.write_permission);
		
		this.formPanel.baseParams.company_id=0;		
		this.formPanel.baseParams.contact_id=0;		
		
		this.parent_project_id=this.formPanel.baseParams.parent_project_id=config.parent_project_id;
		
		this.propertiesPanel.show();		
			
		this.setProjectId(config.project_id);
		
		if(config.project_id>0)
		{

			//this.tabPanel.hideTabStripItem(this.associationsPanel);
			this.formPanel.load({
				url : GO.url('projects/project/load'),
				
				success:function(form, action)
				{
					
					this.setWritePermission(action.result.data.write_permission);
					
					this.formPanel.baseParams.company_id=action.result.data.company_id;
					this.formPanel.baseParams.contact_id=action.result.data.contact_id;
					this.parent_project_id=this.formPanel.baseParams.parent_project_id=action.result.data.parent_project_id;

					this.selectUser.setRemoteText(action.result.remoteComboTexts.responsible_user_id);

					this.selectType.setRemoteText(action.result.remoteComboTexts.type_id);
					
					if(this.selectCalendar)
						this.selectCalendar.setRemoteText(action.result.remoteComboTexts.calendar_id);
					
					if(this.selectTasklist)
						this.selectTasklist.setRemoteText(action.result.remoteComboTexts.tasklist_id);

					this.selectType.setDisabled(action.result.data.permission_level<GO.permissionLevels.writeAndDelete );
					this.templateSelect.setDisabled(action.result.data.permission_level<GO.permissionLevels.writeAndDelete );
					this.applyTemplate(action.result.data.template);

					//applytemplate might have rendered new form fields
					var v = Ext.apply(action.result.data, config.values);
					this.setValues(v);
					
					GO.projects.ProjectDialog.superclass.show.call(this);
				},
				failure:function(form, action)
				{
					GO.errorDialog.show(action.result.feedback)
				},
				scope: this
				
			});
		}else 
		{
			var abField = this.formPanel.form.findField('addressbook');
			if(abField)
				abField.selectFirst();

			var calField = this.formPanel.form.findField('calendar');
			if(calField)
				calField.selectFirst();

			var tasklistField = this.formPanel.form.findField('tasklist');
			if(tasklistField)
				tasklistField.selectFirst();

			this.setWritePermission(true);
			
			this.selectType.selectFirst();
			this.formPanel.form.findField('status_id').selectFirst();
		
			this.setValues(config.values);

			this.applyTemplate();
			GO.projects.ProjectDialog.superclass.show.call(this);
		}

		// if the newMenuButton from another passed a linkTypeId then set this
		// value in the select link field
		if (config.link_config) {
			this.link_config = config.link_config;
			if (config.link_config.modelNameAndId) {
				this.selectLinkField.setValue(config.link_config.modelNameAndId);
				this.selectLinkField.setRemoteText(config.link_config.text);
			}
		}
	},
	
	setWritePermission : function(writePermission)
	{
		this.buttons[0].setDisabled(!writePermission);
		this.buttons[1].setDisabled(!writePermission);
	},
	
	setValues : function(values)
	{
		if(values)
		{
			for(var key in values)
			{
				var field = this.formPanel.form.findField(key);
				if(field)
				{
					field.setValue(values[key]);
				}
			}
		}
		
	},
	setProjectId : function(project_id, noreload)
	{
		this.formPanel.form.baseParams['id']=project_id;
		this.project_id=project_id;

		if(this.createType){
			this.createType.getEl().up('.x-form-item').setDisplayed(project_id==0);

			this.newTypeName.getEl().up('.x-form-item').setDisplayed(false);
			this.newTypeName.allowBlank=true;
		}
		
		this.selectLinkField.getEl().up('.x-form-item').setDisplayed(project_id==0);
		
		if(this.feesPanel)
			this.feesPanel.setProjectId(project_id);

		this.expensesPanel.setProjectId(project_id, noreload);
		this.incomesPanel.setProjectId(project_id, noreload);
	},
	
	submitForm : function(hide){

		var params={};
		if(this.expensesPanel.store.loaded){
			params['expenses']=Ext.encode(this.expensesPanel.getGridData());
		}
		if(this.incomesPanel.store.loaded){
			params['incomes']=Ext.encode(this.incomesPanel.getGridData());
		}

		if(this.feesPanel&& this.feesPanel.store.loaded){
			params['fees']=Ext.encode(this.feesPanel.getGridData());
		}
		
		if(!GO.settings.modules.projects.write_permission)
			params.type_id=this.selectType.getValue();

		this.formPanel.form.submit(
		{
			url:GO.url('projects/project/submit'),
			params: params,
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action){

				if(action.result.parent_project_id)
				{
					this.parent_project_id = action.result.parent_project_id;
				}

				if(action.result.new_expenses)
				{
					if(GO.currencies){
						//reload store for converted amounts
						this.expensesPanel.store.load();
					}else
					{
						this.expensesPanel.setIds(action.result.new_expenses);
					}
				}

				if(action.result.new_incomes)
				{
					if(GO.currencies){
						//reload store for converted amounts
						this.incomesPanel.store.load();
					}else
					{
						this.incomesPanel.setIds(action.result.new_incomes);
					}
				}
				
				if(action.result.id)
				{
					this.setProjectId(action.result.id, true);
					
					this.nameField.setValue(this.nameField.getValue().replace('{autoid}',action.result.id));
				}

				if(action.result.type_id){					
					this.selectType.store.reload({
						callback:function(){
							this.selectType.setValue(action.result.type_id);
						},
						scope:this
					});
				}

				if (this.link_config && this.link_config.callback) {
					this.link_config.callback.call(this);
				}

				this.expensesPanel.store.commitChanges();

				if(this.feesPanel)
					this.feesPanel.store.commitChanges();
				
				this.fireEvent('save', this, this.project_id, this.parent_project_id);	
				
				GO.dialog.TabbedFormDialog.prototype.refreshActiveDisplayPanels.call(this);
				
				if(hide)
				{
					this.hide();	
				}
			},		
			failure: function(form, action) {
				if(action.failureType == 'client')
				{					
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);			
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope: this
		});		
	},

	applyTemplate : function(templateData){
		var showCustomerField = true;
		var showContactField = true;
		var showResUserIdField = true;
		var showStatusDate=true;
		var showBudgetFees=true;
		var showExpenses=true;
		var showIncomes=true;
		var showCalendar=false;
		var showTasklist=false;


//		if(this.loadedTemplateID != this.templateSelect.getValue()){
			if(!templateData){
				var record = GO.projects.templatesStore.getById(this.templateSelect.getValue());
				if(record)
					templateData=record.data;
			}else
			{
				this.templateSelect.setRemoteText(templateData.name);
			}
			if(templateData)
				this.loadedTemplateID=templateData.id;


			if(this.templatePanels){

				for(var i=0,count=this.templatePanels.length;i<count;i++)
				{
					//remove will destoy tab. Without destorying form elements are note
					//removed from the Ext.form.BasicForm which causes problems.



					//hack to remove formfields from basicform
					//this.formPanel.processRemove(this.templatePanels[i]);

					//this.templatePanels[i].items.each(this.formPanel.form.remove, this.formPanel.form);

					this.tabPanel.remove(this.templatePanels[i], true);
				}
			}

			if(templateData)
			{
				var defaultStatusId = templateData.default_status_id;
				if(defaultStatusId>0 && this.project_id==0){
					this.formPanel.form.findField('status_id').setValue(defaultStatusId);
				}

				var defaultTypeId = templateData.default_type_id;
				if(defaultTypeId>0 && this.project_id==0){
					this.selectType.setValue(defaultTypeId);

					if(templateData.default_type_name)
						this.selectType.setRemoteText(templateData.default_type_name);
				}

				this.setTitle(templateData.name);
				var fieldString = templateData.fields;
				var fields = fieldString.split(',');
				showCustomerField=fields.indexOf('customer')>-1;
				showContactField=fields.indexOf('contact')>-1;
				showResUserIdField=fields.indexOf('responsible_user_id')>-1;
				showStatusDate=fields.indexOf('status_date')>-1;
				showBudgetFees=fields.indexOf('budget_fees')>-1;
				showExpenses=fields.indexOf('expenses')>-1;
				showIncomes=fields.indexOf('incomes')>-1;
				showCalendar=fields.indexOf('calendar')>-1;
				showTasklist=fields.indexOf('tasklist')>-1;

				if(GO.projects.templates && GO.projects.templates[templateData.id])
				{
					//get the values because panels that are destroyed might contain fields
					//that will be added empty again.
					var orgValues = this.formPanel.form.getValues();					

					this.templatePanels=[];

					for(var i=0,count=GO.projects.templates[templateData.id].length;i<count;i++)
					{
						//Don't keep it because formpanels need to be destroyed and recreated
						this.templatePanels.push(this.tabPanel.add(GO.projects.templates[templateData.id][i]));
					}

					this.tabPanel.doLayout();

					this.formPanel.form.setValues(orgValues);
				}
			}else
			{
				this.setTitle(GO.projects.lang.project);
				this.tabPanel.items.each(function(p){
					if(p.category_id)
						this.tabPanel.unhideTabStripItem(p.id);
				}, this);

				this.templatePanels=[];
				if(GO.customfields && GO.customfields.types["GO_Projects_Model_Project"])
				{
					for(var i=0;i<GO.customfields.types["GO_Projects_Model_Project"].panels.length;i++)
					{
						this.templatePanels.push(this.tabPanel.add(GO.customfields.types["GO_Projects_Model_Project"].panels[i]));
					}
				}
			}

			if(this.customerField)
				this.customerField.getEl().up('.x-form-item').setDisplayed(showCustomerField);

			if(this.contactField)
				this.contactField.getEl().up('.x-form-item').setDisplayed(showContactField);

			this.selectUser.getEl().up('.x-form-item').setDisplayed(showResUserIdField);
			this.budgetAndFees.getEl().up('.x-form-item').setDisplayed(showBudgetFees);

			if(this.selectCalendar)
					this.selectCalendar.getEl().up('.x-form-item').setDisplayed(showCalendar);
			if(this.selectTasklist)
					this.selectTasklist.getEl().up('.x-form-item').setDisplayed(showTasklist);

			if(this.feesPanel){
				if(showBudgetFees){
					this.tabPanel.unhideTabStripItem(this.feesPanel);
				}else
				{
					this.tabPanel.hideTabStripItem(this.feesPanel);
				}
			}

			if(showExpenses){
				this.tabPanel.unhideTabStripItem(this.expensesPanel);
			}else
			{
				this.tabPanel.hideTabStripItem(this.expensesPanel);
			}

			if(showIncomes){
				this.tabPanel.unhideTabStripItem(this.incomesPanel);
			}else
			{
				this.tabPanel.hideTabStripItem(this.incomesPanel);
			}

			this.statusAndDate.setVisible(showStatusDate);
//		}
		
	},
	
	buildForm : function () {
		
		var items = [];

		var leftCol = new Ext.Panel({
			itemId:'leftCol',
			columnWidth: .6,
			layout:'form',
			border:false
		});

		leftCol.add(this.nameField = new Ext.form.TextField({
			name: 'name',
			anchor: '100%',
			allowBlank:false,
			fieldLabel: GO.lang.strSubject
		}));
		
//		leftCol.add(this.templateSelect = new GO.form.ComboBoxReset({
			leftCol.add(this.templateSelect = new GO.projects.SelectTemplate({
			anchor:'100%',
			fieldLabel: GO.projects.lang.template,
			hiddenName:'template_id',
			store:GO.projects.templatesStore,
			valueField:'id',
			displayField:'name',
			mode: 'local',
			triggerAction: 'all',
			editable: false,
			selectOnFocus:true,
			disabled:!GO.settings.modules.projects.write_permission,
			listeners:{
				change:function(){this.applyTemplate();},
				scope:this
			}
		}));

		if(GO.settings.modules.projects.write_permission){
			leftCol.add(this.createType = new Ext.form.Checkbox({
				name:'create_type',
				hideLabel:true,
				boxLabel:GO.projects.lang.createNewPermissionsType,
				listeners:{
					check:function(cb, checked){
						this.selectType.getEl().up('.x-form-item').setDisplayed(!checked);
						this.selectType.setDisabled(checked);
						this.newTypeName.getEl().up('.x-form-item').setDisplayed(checked);
						this.newTypeName.allowBlank=!checked;
						this.newTypeName.setValue(this.nameField.getValue());
					},
					scope:this
				}
			}));
		

			leftCol.add(this.newTypeName = new Ext.form.TextField({
				name:'new_type_name',
				fieldLabel:GO.lang.strName,
				anchor:'100%'
			}));
		}

		leftCol.add(this.selectType = new GO.projects.SelectType({    		
			anchor:'100%',
			allowBlank:false
		}));


		leftCol.add(this.selectLinkField = new GO.form.SelectLink({
			anchor:'100%'
		}));

		leftCol.add(new GO.form.HtmlComponent({
			html:'<br />',
			hideLabel:true
		}));

		leftCol.add(this.selectUser = new GO.form.SelectUser({
			hiddenName:'responsible_user_id',
			fieldLabel:GO.projects.lang.projectManager,
			anchor:'100%',
			allowBlank:true
		}));
		

		

		if(GO.addressbook)
		{
			this.customerField = new GO.addressbook.SelectCompany({
				anchor:'100%',
				fieldLabel: GO.projects.lang.customer,
				name: 'customer'
			});
			this.customerField.on('select', function(combo, record){
				this.formPanel.baseParams.company_id=record.data.id;
			}, this);
			leftCol.add(this.customerField);
  
			this.contactField = new GO.addressbook.SelectContact({
				anchor:'100%',
				fieldLabel: GO.projects.lang.contact,
				name:'contact'
			});
			this.contactField.on('select', function(combo, record){
				this.formPanel.baseParams.contact_id=record.data.id;
			}, this);
			leftCol.add(this.contactField);
		}


		var rightCol = new Ext.Panel({
			itemId:'rightCol',
			columnWidth: .4,
			layout:'form',
			border:false
		});
		
		var now = new Date();

		this.statusAndDate = new Ext.Panel({
			border:false,
			layout:'form',
			forceLayout:true,
			bodyStyle:'padding:0px',
			items:[{
				xtype:'combo',
				anchor:'100%',
				fieldLabel: GO.projects.lang.status,
				hiddenName:'status_id',
				store:GO.projects.statusesStore,
				valueField:'id',
				displayField:'name',
				mode: 'local',
				triggerAction: 'all',
				editable: false,
				selectOnFocus:true,
				forceSelection: true,
				allowBlank:false
			},{
				xtype:'datefield',
				name: 'start_time',
				format: GO.settings['date_format'],
				allowBlank:true,
				fieldLabel: GO.projects.lang.startTime,
				value: now.format(GO.settings.date_format)
			},{
				xtype:'datefield',
				format: GO.settings['date_format'],
				name: 'due_time',
				allowBlank:true,
				fieldLabel: GO.projects.lang.dueAt//,
			//value: now.format(GO.settings.date_format)
			}]
		});

		rightCol.add(this.statusAndDate);
    
		


		if(GO.calendar)
		{
//			this.associationStore = new Ext.data.SimpleStore({
//				loaded : true,
//				fields : ['value', 'text'],
//				data : [
//				['parent', GO.projects.lang.useParentProject],
//				['none', GO.projects.lang.noAssociation],
//				['own', GO.projects.lang.useOwn]
//				]
//			});
//
//
//			rightCol.add(this.associatedCalendarCombo = new GO.form.ComboBox({
//				lastQuery:'', //dirty way for filter
//				anchor:'100%',
//				hiddenName : 'calendar',
//				fieldLabel: GO.projects.lang.associatedCalendar,
//				store : this.associationStore,
//				valueField : 'value',
//				displayField : 'text',
//				mode : 'local',
//				triggerAction : 'all',
//				selectOnFocus : true,
//				forceSelection : true,
//				value:'none'
//			}));
			rightCol.add(this.selectCalendar= new GO.calendar.SelectCalendar());
		}
		
		if(GO.tasks){
			rightCol.add(this.selectTasklist = new GO.tasks.SelectTasklist());
		}


		var description = new Ext.form.TextArea({
			name: 'description',
			anchor: '100%',
			height:100,
			allowBlank:true,
			fieldLabel: GO.lang.strDescription
		});

		//rightCol.add(description);

		this.budgetAndFees = new GO.form.NumberField({
			name: 'units_budget',
			allowBlank:true,
			fieldLabel: GO.projects.lang.unitsBudget,
			anchor:'100%'
		});

		rightCol.add(this.budgetAndFees);

		this.propertiesPanel = new Ext.Panel({
			url: GO.url('projects/project/load'),
			border: false,
			baseParams: {},
			title:GO.lang['strProperties'],			
			cls:'go-form-panel',
			layout:'column',
			items:[leftCol, rightCol,{
					columnWidth:1,
					layout:'form',border:false,
					items:[description]
			}]
		});
		

		var items  = [this.propertiesPanel];

		if(GO.settings.modules.timeregistration){
			this.feesPanel = new GO.projects.ProjectFeesPanel({
				disabled:true,
				title:GO.projects.lang.overrideDefaultFees,
				listeners:{
					show:function(){
						if(!this.store.loaded)
							this.store.load();
					},
					scope:this.userFeesPanel
				}
			});
			items.push(this.feesPanel);
		}
		


		this.expensesPanel = new GO.projects.ExpensesGrid({
			title:GO.projects.lang.expenses
		});
		this.incomesPanel = new GO.projects.IncomesGrid({
			title:GO.projects.lang.income
		});

		items.push(this.expensesPanel);
		items.push(this.incomesPanel);
		
		/*if(GO.customfields && GO.customfields.types["5"])
		{
			for(var i=0;i<GO.customfields.types["5"].panels.length;i++)
			{			  	
				items.push(GO.customfields.types["5"].panels[i]);
			}
		}*/

 
		this.tabPanel = new Ext.TabPanel({
			activeTab: 0,
			deferredRender: false,
			border: false,
			items: items,
			anchor: '100% 100%',
			enableTabScroll:true
		});
    
		this.formPanel = new Ext.form.FormPanel({
			waitMsgTarget:true,
			url: GO.url('projects/project/load'),
			border: false,
			baseParams: {
				parent_project_id:0
			},
			items:this.tabPanel,
			labelWidth:125
		});    
	}
});
