/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @version $Id: ProjectFeesPanel.js 15897 2013-05-21 09:02:45Z mschering $
 * @copyright Copyright Intermesh
 * @author Merijn Schering <mschering@intermesh.nl>
 */



GO.projects.ProjectFeesPanel = function(config){
	if(!config)
	{
		config = {};
	}
	
	config.layout='fit';
	config.autoScroll=true;
	config.split=true;

	var fields ={
		fields:['user_id','user_name','internal_value', 'external_value'],
		columns:[	{
			header: GO.lang.strUser,
			dataIndex: 'user_name'
		},{
			header: GO.projects.lang.internalFee,
			dataIndex: 'internal_value',
			editor: new GO.form.NumberField({
				allowBlank: false
			}),
			align:'right'
		},{
			header: GO.projects.lang.externalFee,
			dataIndex: 'external_value',
			editor: new GO.form.NumberField({
				allowBlank: false
			}),
			align:'right'
		}]
	};
	config.store = new GO.data.JsonStore({
		url: GO.settings.modules.projects.url+ 'json.php',
		baseParams: {
			task: 'user_fees',
			limit:parseInt(GO.settings['max_rows_list']),
			project_id:0
		},
		root: 'results',
		id: 'id',
		totalProperty:'total',
		fields: fields.fields,
		remoteSort: true
	});

	config.bbar = new Ext.PagingToolbar({
		cls: 'go-paging-tb',
		store: config.store,
		pageSize: parseInt(GO.settings['max_rows_list']),
		displayInfo: true,
		displayMsg: GO.lang['displayingItems'],
		emptyMsg: GO.lang['strNoItems']
	});

	var columnModel =  new Ext.grid.ColumnModel({
		defaults:{
			sortable:true
		},
		columns:fields.columns
	});

	
	config.cm=columnModel;
	config.view=new Ext.grid.GridView({
		autoFill: true,
		forceFit: true,
		emptyText: GO.lang['strNoItems']
	});
	config.sm=new Ext.grid.RowSelectionModel();
	config.loadMask=true;

	config.clicksToEdit=1;



	GO.projects.ProjectFeesPanel.superclass.constructor.call(this, config);

};
Ext.extend(GO.projects.ProjectFeesPanel, Ext.grid.EditorGridPanel,{
	setProjectId : function(project_id){
		this.store.baseParams.project_id=project_id;
		this.setDisabled(GO.util.empty(project_id));

		this.store.removeAll();
		this.store.loaded=false;
	},

	getGridData : function(){

		var data = {};

		for (var i = 0; i < this.store.data.items.length;  i++)
		{
			var r = this.store.data.items[i].data;

			data[i]={};

			for(var key in r)
			{
				data[i][key]=r[key];
			}
		}

		return data;
	}
});
