GO.projects.ProjectsPanel = function(config){
	
	if(!config)
	{
		config = {};
	}

	config.border=true;
	config.paging=true;
	config.stateId='pm-projects-panel';

	//config.enableColumnHide=false;
	//config.enableColumnMove=false;
	
	this.fields = {
		fields:['id', 'name', 'customer', 'responsible_user_name', 'contact', 'status_name', 'start_time', 'due_time', 'units_budget','type_name','template_name','mtime','ctime', 'icon','path'],
		columns:[
		{
			header:'ID',
			dataIndex: 'id',
			hidden:false,
			sortable:true,
			width:50
		},{
			header:GO.lang['strName'],
			dataIndex: 'name',
			sortable:true,
			renderer:function(v, meta, r){				
				if(!GO.util.empty(r.data.icon))
				{
					return '<img src="'+r.data.icon+'" style="vertical-align:middle;margin-right:4px;width:16px;height:16px;" />'+v;
				}else
				{
					return '<div class="go-grid-icon go-model-icon-GO_Projects_Model_Project">'+v+'</div>';
				}
			},
			width:150
		},{
			header:GO.projects.lang.path,
			dataIndex: 'path',
			sortable:false,
			width:150
		},{
			header:GO.projects.lang.customer,
			dataIndex: 'customer',
			sortable:true,
			width:150,
			editor: GO.addressbook ? new GO.addressbook.SelectCompany({valueField: 'name_and_name2'}) : new Ext.form.TextField()
		},{
			header:GO.projects.lang.projectManager,
			dataIndex: 'responsible_user_name',
			sortable:true,
			width:150,
			editor: new GO.form.SelectUser()
		},{
			header:GO.projects.lang.contact,
			dataIndex: 'contact',
			sortable:true,
			hidden:true,
			width:150,
			editor: GO.addressbook ? new GO.addressbook.SelectContact({	valueField: 'name'}) : new Ext.form.TextField()
		},{
			header:GO.projects.lang['status'],
			dataIndex: 'status_name',
			sortable:true,
			width:100,
			editor: new GO.projects.SelectStatus()
		},{
			header:GO.projects.lang.startTime,
			dataIndex: 'start_time',
			sortable:true,
			width:80
		},{
			header:GO.projects.lang.dueAt,
			dataIndex: 'due_time',
			sortable:true,
			width:80
		},{
			header:GO.projects.lang.unitsBudget,
			dataIndex: 'units_budget',
			sortable:true,
			width:80
		},{
			header:GO.projects.lang.type,
			dataIndex: 'type_name',
			sortable:true,
			hidden:true,
			width:80,
			editor: new GO.projects.SelectType()
		},{
			header:GO.projects.lang.template,
			dataIndex: 'template_name',
			sortable:true,
			hidden:true,
			width:80,
			editor: new GO.projects.SelectTemplate()
		},{
			header: GO.lang.strMtime,
			dataIndex:'mtime',
			hidden:true,
			width:110,
			sortable:true
		},{
			header: GO.lang.strCtime,
			dataIndex:'ctime',
			hidden:true,
			width:110,
			sortable:true
		}
		]
	}

	if(GO.customfields)
	{
		GO.customfields.addColumns("GO_Projects_Model_Project", this.fields);
	}
	
	config.columns=this.fields.columns;
	
	config.store = new GO.data.JsonStore({
		url: GO.url('projects/project/store'),
		baseParams: {
			'parent_project_id' : "0"
		},
		remoteSort: true,
		fields:this.fields.fields
	});
	
	config.store.on('load', function(){
		this.addButton.setDisabled(!this.store.reader.jsonData.write_permission);
		this.deleteButton.setDisabled(!this.store.reader.jsonData.write_permission);
		
		this.upButton.setDisabled(this.store.reader.jsonData.parent_project_id<0);

		this.parentProject = this.store.reader.jsonData.parent_project;
	},this);
	
	config.view=new Ext.grid.GridView({
		emptyText: GO.lang.strNoItems
	}),
	config.sm=new Ext.grid.RowSelectionModel();
	config.enableDragDrop=true;
	config.ddGroup='ProjectsDD';
	config.loadMask=true;
	
	this.searchField = new GO.form.SearchField({
		store: config.store,
		width:320
	});
	
	config.tbar= config.tbar || [];
		
	config.tbar.push(this.upButton = new Ext.Button({
		iconCls: 'btn-up',
		text: GO.lang.up,
		disabled:true,
		cls: 'x-btn-text-icon',
		handler: function(){
			this.store.baseParams.parent_project_id=this.store.reader.jsonData.parent_project_id;
			this.store.load();
		},
		scope: this
	}));

	config.tbar.push(this.addButton = new Ext.Button({
		iconCls: 'btn-add',
		text: GO.lang['cmdAdd'],
		cls: 'x-btn-text-icon',
		disabled:true,
		handler: function(){
			if(GO.projects.max_projects>0 && this.store.totalLength>=GO.projects.max_projects)
			{
				Ext.Msg.alert(GO.lang.strError, GO.projects.lang.maxProjectsReached);
			}else
			{
				this.ownerCt.projectPanel.reset();
				GO.projects.showProjectDialog({
					parent_project_id: this.store.baseParams.parent_project_id/*,
					values:{
						type_id:this.parentProject ? this.parentProject.type_id : null
					}*/
					});
			}
		},
		scope: this
	}));
	
	config.deleteConfig={
		callback:function(config){
			this.ownerCt.projectPanel.gridDeleteCallback(config);
			this.fireEvent('delete', this);
		},
		scope:this
	};
		
	config.tbar.push(this.deleteButton = new Ext.Button({	
		iconCls: 'btn-delete',
		text: GO.lang['cmdDelete'],
		cls: 'x-btn-text-icon',
		disabled:true,
		handler: function(){
			this.deleteSelected();
		},
		scope: this
	}));
	
	config.tbar.push('-');
	
	config.tbar.push(this.exportButton = new Ext.Button({
		iconCls:'btn-export',
		text:GO.lang.cmdExport,
		handler:function(){
			if(!this.exportDialog)
			{
				this.exportDialog = new GO.ExportGridDialog({
					url: 'projects/project/export',
					name: 'projects',
					documentTitle:'ExportProject',
					colModel: this.getColumnModel(),
					beforeSubmit : function(columns, headers){
						headers.push(GO.lang.strDescription);
						columns.push("description");
					}
				});
			}
			this.exportDialog.show();
		},
		scope:this
	}));
		
//		config.tbar.push('-');

//	config.tbar.push({
//		iconCls: 'btn-export',
//		text: GO.lang.cmdExport,
//		cls: 'x-btn-text-icon',
//		handler:function(){
//			var config = {};
//
//			config.colModel = this.getColumnModel();
//			config.title = GO.projects.lang.projects;
//
//			var query = this.searchField.getValue();
//			if(!GO.util.empty(query))
//			{
//				config.subtitle= GO.lang.searchQuery+': '+query;
//			}else
//			{
//				config.subtitle='';
//			}
//
//			if(!this.exportDialog)
//			{
//				this.exportDialog = new GO.ExportQueryDialog({
//					query:'projects'
//				});
//			}
//			this.exportDialog.show(config);
//
//		},
//		scope: this
//	});

	
	config.tbar.push('-');
	config.tbar.push(GO.lang['strSearch']+': ');
	config.tbar.push(this.searchField);

	if(GO.projects.max_projects>0)
	{
		config.bbar = new Ext.PagingToolbar({
			store: config.store,
			pageSize: parseInt(GO.settings['max_rows_list']),
			displayInfo: true,
			cls:'go-paging-tb',
			displayMsg: GO.lang['displayingItems']+'. '+GO.lang.strMax+' '+GO.projects.max_projects,
			emptyMsg: GO.lang['strNoItems']
		});
	}
	
	GO.projects.ProjectsPanel.superclass.constructor.call(this, config);
	
	this.addEvents({
		'delete' : true
	});

};

Ext.extend(GO.projects.ProjectsPanel, GO.grid.GridPanel, {

	parentProject : false,
	
	afterRender : function()
	{
		GO.projects.ProjectsPanel.superclass.afterRender.call(this);
		this.store.load();
	}
});
