/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @version $Id: ReportPageDialog.js 15897 2013-05-21 09:02:45Z mschering $
 * @copyright Copyright Intermesh
 * @author Merijn Schering <mschering@intermesh.nl>
 */
GO.projects.ReportPageDialog = function(config){	
	if(!config)
	{
		config={};
	}
	this.buildForm();
	var focusFirstField = function(){
		this.formPanel.items.items[0].focus();
	};
	config.collapsible=true;
	config.maximizable=true;
	config.layout='border';
	config.modal=false;
	config.resizable=true;
	config.width=750;
	config.height=500;
	config.closeAction='hide';
	config.title= GO.projects.lang.reportPage;					
	config.items= [this.formPanel,this.autoDataPanel];
	config.focus= focusFirstField.createDelegate(this);
	config.buttons=[{
		text: GO.lang['cmdOk'],
		handler: function(){
			this.submitForm(true);
		},
		scope: this
	},{
		text: GO.lang['cmdApply'],
		handler: function(){
			this.submitForm();
		},
		scope:this
	},{
		text: GO.lang['cmdClose'],
		handler: function(){
			this.hide();
		},
		scope:this
	}
	];
	GO.projects.ReportPageDialog.superclass.constructor.call(this, config);
	this.addEvents({
		'save' : true
	});
}
Ext.extend(GO.projects.ReportPageDialog, Ext.Window,{
	show : function (report_page_id, config) {
		if(!this.rendered)
		{
			this.render(Ext.getBody());
		}
		this.formPanel.form.reset();
		if(!report_page_id)
		{
			report_page_id=0;			
		}
		this.setReportPageId(report_page_id);
		if(this.report_page_id>0)
		{
			this.formPanel.load({
				url : GO.settings.modules.projects.url+'json.php',
				waitMsg:GO.lang['waitMsgLoad'],
				success:function(form, action)
				{					
					GO.projects.ReportPageDialog.superclass.show.call(this);
				},
				failure:function(form, action)
				{
					GO.errorDialog.show(action.result.feedback)
				},
				scope: this				
			});
		}else 
		{
			GO.projects.ReportPageDialog.superclass.show.call(this);
		}
	},
	setReportPageId : function(report_page_id)
	{
		this.formPanel.form.baseParams['report_page_id']=report_page_id;
		this.report_page_id=report_page_id;
	},
	submitForm : function(hide){
		this.formPanel.form.submit(
		{
			url:GO.settings.modules.projects.url+'action.php',
			params: {
				'task' : 'save_report_page'
			},
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action){
				if(action.result.report_page_id)
				{
					this.setReportPageId(action.result.report_page_id);
				}				
				this.fireEvent('save', this, this.report_page_id);				
				if(hide)
				{
					this.hide();	
				}
			},		
			failure: function(form, action) {
				if(action.failureType == 'client')
				{					
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);			
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope: this
		});		
	},
	buildForm : function () {

		var autodata = [
		['{date}',GO.lang['strDate']],
		['{name}',GO.lang.strName],
		['{description}',GO.lang.strDescription],
		['{path}','Project path'],
		['{start_time}',GO.projects.lang.startTime],
		['{due_time}',GO.projects.lang.dueAt],
		['{status_name}',GO.projects.lang.status],
		['{customer}',GO.projects.lang.customer],
		['{contact}',GO.projects.lang.contact],
		['{units_budget}',GO.projects.lang.unitsBudget]
		];	


		var items = [new Ext.Panel({
			title:GO.projects.lang.standardProjectFields,
			autoScroll:true,
			items:new GO.grid.SimpleSelectList({
				store:  new Ext.data.SimpleStore({
					fields: ['value', 'name'],
					data : autodata
				}),
				listeners:{
					scope:this,
					click:function(dataview, index){
						this.formPanel.form.findField('content').insertAtCursor(dataview.store.data.items[index].data.value);
						dataview.clearSelections();
					}
				}
			})
		})];

		if(GO.customfields){
			autodata=[];
			if(GO.customfields.types["5"] && GO.customfields.types["5"].panels.length)
			{
				for(var i=0;i<GO.customfields.types["5"].panels.length;i++)
				{
					var p = GO.customfields.types["5"].panels[i];
					for(var c=0;c<p.customfields.length;c++){						
							autodata.push(['{'+p.customfields[c].dataname+'}',p.customfields[c].name]);
					}
				}
			}
			if(autodata.length){
				items.push(new Ext.Panel({
					autoScroll:true,
					title:GO.projects.lang.customProjectFields,
					items:new GO.grid.SimpleSelectList({
						store:  new Ext.data.SimpleStore({
							fields: ['value', 'name'],
							data : autodata
						}),
						listeners:{
							scope:this,
							click:function(dataview, index){
								this.formPanel.form.findField('content').insertAtCursor(dataview.store.data.items[index].data.value);
								dataview.clearSelections();
							}
						}
					})
				}));
			}

			autodata=[];
			if(GO.customfields.types["14"] && GO.customfields.types["14"].panels.length)
			{
				for(var i=0;i<GO.customfields.types["14"].panels.length;i++)
				{
					var p = GO.customfields.types["14"].panels[i];
					for(var c=0;c<p.customfields.length;c++){												
							autodata.push(['{'+p.customfields[c].dataname+'}',p.customfields[c].name]);
					}
				}
			}
			if(autodata.length){
				items.push(new Ext.Panel({
					autoScroll:true,
					title:GO.projects.lang.customReportFields,
					items:new GO.grid.SimpleSelectList({
						store:  new Ext.data.SimpleStore({
							fields: ['value', 'name'],
							data : autodata
						}),
						listeners:{
							scope:this,
							click:function(dataview, index){
								this.formPanel.form.findField('content').insertAtCursor(dataview.store.data.items[index].data.value);
								dataview.clearSelections();
							}
						}
					})
				}));
			}
		}

		this.autoDataPanel = new Ext.Panel({
			region:'east',
			layout:'accordion',
			border:false,
			autoScroll:true,
			width: 180,
			split:true,
			resizable:true,
			items:items
		});

		this.formPanel = new Ext.form.FormPanel({
			region:'center',
			waitMsgTarget:true,
			baseParams:{
				task: 'report_page',
				report_template_id:0
			},
			url: GO.settings.modules.projects.url+'action.php',
			border: false,
			cls:'go-form-panel',
			items:[{
				xtype: 'textfield',
				name: 'title',
				anchor: '100%',
				fieldLabel: GO.projects.lang.title
			},{
				xtype: 'textfield',
				name: 'subtitle',
				anchor: '100%',
				fieldLabel: GO.projects.lang.subtitle
			},{
				xtype:'combo',
				fieldLabel : 'Page orientation',
				hiddenName : 'landscape',
				store : new Ext.data.SimpleStore({
						fields : ['value', 'text'],
						data : [
							['0', 'Portrait'],
							['1', 'Landscape']
						]
				}),
				value : 'portrait',
				valueField : 'value',
				displayField : 'text',
				mode : 'local',
				triggerAction : 'all',
				editable : false,
				selectOnFocus : true,
				forceSelection : true
			},{
				xtype: 'textarea',
				name: 'content',
				anchor: '100% -75',
				hideLabel:true,
				plugins:new GO.plugins.InsertAtCursorTextareaPlugin()
			}]
		});
	}
});
