/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @copyright Copyright Intermesh
 * @version $Id: ReportPanel.js 16728 2013-08-28 10:11:47Z mschering $
 * @author Merijn Schering <mschering@intermesh.nl>
 */


 
GO.projects.ReportPanel = function(config){
	
	
	if(!config)
	{
		config={};
	}
	

	this.groupBy = new Ext.form.ComboBox({
		width:240,
		fieldLabel: GO.projects.lang.groupHoursBy,
		hiddenName:'group_by',
		store: new Ext.data.SimpleStore({
			fields: ['value', 'text'],
			data : [
			['project_id', GO.projects.lang.projects],
			['user_id', GO.lang.users],
			['customer', GO.lang.customer]
			]
          
		}),
		value:'project_id',
		valueField:'value',
		displayField:'text',
		mode: 'local',
		triggerAction: 'all',
		editable: false,
		selectOnFocus:true,
		forceSelection: true
	});
    
	var now = new Date();
	var lastMonth = now.add(Date.MONTH, -1);
	var startOfLastMonth = lastMonth.getFirstDateOfMonth();
	var endOfLastMonth = lastMonth.getLastDateOfMonth();
  
	this.startDate = new Ext.form.DateField({
		width:240,
		name: 'start_date',
		format: GO.settings['date_format'],
		allowBlank:true,
		fieldLabel: GO.lang.strStart,
		value: startOfLastMonth.format(GO.settings.date_format),
		listeners : {
			change : {
				fn : this.setDateInput,
				scope: this
			}
		}
	});
			
	this.endDate = new Ext.form.DateField({  
		width:240,
		name: 'end_date',
		format: GO.settings['date_format'],
		allowBlank:true,
		fieldLabel: GO.lang.strEnd,
		value: endOfLastMonth.format(GO.settings.date_format),
		listeners : {
			change : {
				fn : this.setDateInput,
				scope: this
			}
		}
	});

	this.selectUser = new GO.form.ComboBoxReset({
		width:240,
		fieldLabel: GO.lang.strUser,
		store : new GO.data.JsonStore({
			url: GO.url('core/users'),
			baseParams: {
				'task':'users'
			},
			root: 'results',
			totalProperty: 'total',
			id: 'id',
			fields:['id','name','email','username'],
			remoteSort: true
		}),
		displayField: 'name',
		hiddenName:'user_id',
		value: '',
		valueField: 'id',
		triggerAction: 'all',
		selectOnFocus:true,
		forceSelection: true,
		disabled:!GO.settings.modules.projects.write_permission,
		pageSize: parseInt(GO.settings['max_rows_list'])
	});
	
	
	this.setReportPanel =new Ext.form.FormPanel({
		region:'north',
		title:GO.projects.lang.reports,
		waitMsgTarget:true,
		bodyStyle:'padding:10px',
		height:220,
		layout:'column',
		keys:[{
        key: Ext.EventObject.ENTER,
        fn: function(key, e){
        	this.loadReport();
        },
        scope:this
    }],
		defaults:{
			border:false,
			layout:'form'
		},
		items:[
		{
			border:false,
			cls: 'go-form-text-panel',
			html: GO.projects.lang.datefieldsInfo,
			columnWidth:1
		},
		{
			columnWidth:.5,
			items:[
			this.groupBy,
			this.selectUser,
			{
				xtype:'textfield',
				fieldLabel:GO.lang.strSearch,
				name:'query',
				width:240
			}]
		},{
			columnWidth:.5,
			items:[{
				layout:'table',
				border:false,
				defaults:{
					border:false,
					layout:'form'
				},
				items:[
				{
					items:this.startDate
				},{
					bodyStyle:'padding-left:5px',
					items:new Ext.Button({
						text: GO.projects.lang.previousMonth,
						handler: function(){
							this.changeMonth(-1);
						},
						scope:this
					})
				}]
			}, {
				layout:'table',
				border:false,
				defaults:{
					border:false,
					layout:'form'
				},
				items:[
				{
					items:this.endDate
				},{
					bodyStyle:'padding-left:5px',
					items:new Ext.Button({
						text: GO.projects.lang.nextMonth,
						handler: function(){
							this.changeMonth(1);
						},
						scope:this
					})
				}]
			}

			]
		}
		],

		buttonAlign:'left',
		buttons:[
		
		{
			text: GO.lang['cmdApply'],
			handler: this.loadReport,
			scope:this
		},{
			text: GO.lang['cmdReset'],
			handler: function(){this.setReportPanel.form.reset();},
			scope:this
		},{
			
			text: GO.lang.cmdExport,
			scope: this,
			handler: function(){
				if(!this.exportDialog)
				{
					this.exportDialog = new GO.ExportQueryDialog({
						query:'project_report_totals'
					});
				}
				
				var html = "<table>"+
						"<tr><td width=\"100\">"+GO.projects.lang.groupHoursBy+':</td><td>'+this.groupBy.getRawValue()+"</td></tr>";
					
				if(this.selectUser.getRawValue()!="")
					html +=	"<tr><td width=\"100\">"+GO.lang.strUser+':</td><td>'+this.selectUser.getRawValue()+"</td></tr>";
					
				html += "<tr><td width=\"100\">"+GO.lang.strStart+':</td><td>'+this.startDate.getRawValue()+"</td></tr>"+
						"<tr><td width=\"100\">"+GO.lang.strEnd+':</td><td>'+this.endDate.getRawValue()+"</td></tr></table>";
				
				this.exportDialog.show({
					colModel:this.reportGrid.getColumnModel(),
					title:GO.projects.lang.totalsReport,
					searchQuery: this.setReportPanel.form.findField('query').getValue(),					
					html:html
				});
			}
		}/*,
			
		{
			text: GO.lang.cmdPrint,
			handler: function()
			{
				if(!this.printDialog)
				{
					this.printDialog = new GO.projects.PrintDialog();
				}
				this.printDialog.show(this.groupBy.getValue(), this.selectUser.getValue(), this.startDate.getRawValue(), this.endDate.getRawValue(), this.reportGrid.getColumnModel());
			},
			scope:this
		}*/
		]
	});
	
	this.setReportPanel.on('save', function(){
		GO.projects.reportGrid.store.reload();
	}, this);
	
	this.reportGrid = new GO.projects.ReportGrid({
		region:'center',
		//id:config.id+'-report-grid',
		border:true
	});
			
	config.layout='border';
	config.items=[this.setReportPanel,this.reportGrid];
	
	GO.projects.ReportPanel.superclass.constructor.call(this, config);	
}

Ext.extend(GO.projects.ReportPanel, Ext.Panel,{
	
	setDateInput : function(field)
	{
		if(this.startDate.getValue() > this.endDate.getValue())
		{
			if(field.name == 'end_date')
			{
				this.startDate.setValue(this.endDate.getValue());
			}else
			{
				this.endDate.setValue(this.startDate.getValue());
			}
		}
	},
	changeMonth : function(increment)
	{
		var date = this.startDate.getValue();
		date = date.add(Date.MONTH, increment);
		this.startDate.setValue(date.getFirstDateOfMonth().format(GO.settings.date_format));
		this.endDate.setValue(date.getLastDateOfMonth().format(GO.settings.date_format));
		
		this.loadReport();
	},
	
	loadReport : function(){
		this.reportGrid.store.baseParams.group_by=this.groupBy.getValue();
		this.reportGrid.store.baseParams.user_id=this.selectUser.getValue();
		
		var startDate = this.startDate.getValue();
		var endDate = this.endDate.getValue();		

		this.reportGrid.store.baseParams.query=this.setReportPanel.form.findField('query').getValue();
		this.reportGrid.store.baseParams.start_date=startDate ? startDate.format(GO.settings.date_format) : '';
		this.reportGrid.store.baseParams.end_date=endDate ? endDate.format(GO.settings.date_format) : '';
		this.reportGrid.store.load();
		
//		if(this.printDialog)
//		{
//			this.printDialog.setValues(this.groupBy.getValue(), this.selectUser.getValue(), this.startDate.getRawValue(), this.endDate.getRawValue(), this.reportGrid.getColumnModel());
//		}
	},
	
	afterRender : function(){
		
		this.loadReport();
		
		GO.projects.ReportPanel.superclass.afterRender.call(this);
	},
	
	onShow : function() {
		GO.projects.ReportPanel.superclass.onShow.call(this);

		if (!this.reportGrid.store.loaded)
			this.loadReport();
	}
});