/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @copyright Copyright Intermesh
 * @author Wilmar van Beusekom <wilmar@intermesh.nl>
 */
GO.projects.ReportTemplateCSVDialog = function(config){	
	if(!config)
	{
		config={};
	}

	config.collapsible=true;
	config.maximizable=true;
	config.layout='fit';
	config.modal=false;
	config.resizable=true;
	config.width=900;
	config.height=500;
	config.closeAction='hide';
	config.title= GO.projects.lang.reportTemplateCSV;					
	this.buildForm();
	config.items= this.formPanel;
	config.buttons=[{
		text: GO.lang['cmdOk'],
		handler: function(){
			this.submitForm(true);
		},
		scope: this
	},{
		text: GO.lang['cmdApply'],
		handler: function(){
			this.submitForm();
		},
		scope:this
	},{
		text: GO.lang['cmdClose'],
		handler: function(){
			this.hide();
		},
		scope:this
	}
	];
	GO.projects.ReportTemplateCSVDialog.superclass.constructor.call(this, config);
	this.addEvents({
		'save' : true
	});
}

Ext.extend(GO.projects.ReportTemplateCSVDialog, Ext.Window,{

	show : function (report_template_id, config) {
		
		config = config || {};
		
		if(!this.rendered)
		{
			this.render(Ext.getBody());
		}
		this.formPanel.form.reset();
		this.setReportTemplateId(report_template_id);

		this.formPanel.load({
			url : GO.url('projects/reportTemplate/loadTemplate'),
			waitMsg:GO.lang['waitMsgLoad'],
			success:function(form, action)
			{
				this.selectTagsList.store.loadData(action.result.projectAttributes);
				GO.projects.ReportTemplateCSVDialog.superclass.show.call(this);
			},
			failure:function(form, action)
			{
				GO.errorDialog.show(action.feedback)
			},
			scope: this				
		});
	},
	
	setReportTemplateId : function(report_template_id)
	{
		this.formPanel.form.baseParams['id']=report_template_id;
//		this.tagsGridPanel.store.baseParams['id']=report_template_id;
	},
	
	submitForm : function(hide){
//		var tags = this.autoDataPanels.store.collect('tag',false);
		this.formPanel.form.submit({
			url: GO.url('projects/reportTemplateCSV/submit'),
//			params: {
//				rows : Ext.encode(tags)
//			},
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action){
				if(action.result.id)
				{
					this.setReportTemplateId(action.result.id);
				}				
				this.fireEvent('save', this, this.report_template_id);				
				if(hide)
				{
					this.hide();	
				}
			},		
			failure: function(form, action) {
				if(action.failureType == 'client')
				{					
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);			
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope: this
		});		
	},
	
	buildForm : function () {
//		this.tagsGridPanel = new GO.grid.GridPanel({
//			width: 300,
//			height: 470,
//			title : GO.projects.lang.rowsForCSV,
//			// This store's contents MUST ONLY be filled by the dialog's show component
//			store : new GO.data.JsonStore({
//				baseParams: {},
//				fields: ['tag','label'],
//				remoteSort: true
//			}),
//			cm : new Ext.grid.ColumnModel({
//				columns:[{
//					header: GO.projects.lang.tag,
//					dataIndex: 'tag',
//					hidden : true
//				},{
//					header: GO.lang.strLabel,
//					dataIndex: 'label',
//					sortable : false
//				}]
//			}),
//			view: new Ext.grid.GridView({
//				autoFill: true,
//				forceFit: true,
//				emptyText: GO.lang['strNoItems']
//			}),
//			sm : new Ext.grid.RowSelectionModel(),
//			insertNewRecord : function(tagString,labelString) {
//				var newId = this._getNewRecordId();
//				var newRecord = Ext.data.Record.create([tagString,labelString]);
//				this.store.insert(newId,[newRecord]);
//			},
//			_getNewRecordId : function() {
//				// returns the spot in its store where it wants a new record
//				var selectedRecord = this.getSelectionModel().getSelected();
//				if (selectedRecord==null)
//					return this.store.data.length;
//				else
//					return selectedRecord.data.id;
//			}
//		});

		var leftPanel = new Ext.Panel({
			layout: 'form',
			region: 'center',
			width: 500,
			height: 500,
			labelWidth:200,
			bodyStyle:'padding:5px',
			items: [
				new Ext.form.TextField({
					name : 'name',
					fieldLabel : GO.lang.strName,
					anchor:'-20',
					labelStyle: 'width:50px;',
					style : 'padding-left:5px;',
					allowBlank: false
				}),
				this.labelsTextArea = new Ext.form.TextArea({
					name : 'headers',
					fieldLabel : GO.projects.lang.headers,
					anchor:'-20',
					labelStyle: 'width:50px;',
					style : 'padding-left:5px;',
					height: 170
				}),
				this.tagsTextArea = new Ext.form.TextArea({
					name : 'tags',
					fieldLabel : GO.projects.lang.tags,
					anchor:'-20',
					labelStyle: 'width:50px;',
					style : 'padding-left:5px;',
					height: 170
				})
//				this.tagsGridPanel
			]
		})	
				
		this.autoDataPanels = new Ext.Panel({
			title:GO.addressbook.lang.autoData ,
			autoScroll:true,
			region: 'east',
			width: 300,
			height: 500,
			items : [
				this.selectTagsList = new GO.grid.SimpleSelectList({
					title: GO.projects.lang.projectFields,
					store:  new GO.data.JsonStore({												
						fields: ['label', 'name'],
						remoteSort: true
					}),
					tpl: new Ext.XTemplate( 
						'<tpl for=".">'+
						'<div id="{dom_id}" class="go-item-wrap">{label}</div>'+
						'</tpl>'
					)
				})
			]
		});
		
		this.selectTagsList.on('click',function(dataview,index){
			var record = dataview.store.getAt(index);
			if (this.labelsTextArea.getValue()=="") {
				this.labelsTextArea.setValue(record.data.label);
			} else {
				this.labelsTextArea.setValue(this.labelsTextArea.getValue()+","+record.data.label);
			}
			if (this.tagsTextArea.getValue()=="") {
				this.tagsTextArea.setValue("{"+record.data.name+"}");
			} else {
				this.tagsTextArea.setValue(this.tagsTextArea.getValue()+",{"+record.data.name+"}");
			}
		},this);
		
		this.formPanel = new Ext.form.FormPanel({
			waitMsgTarget:true,
			url: GO.url('projects/reportTemplate/loadCSVTemplate'),
			border: false,
			baseParams: {},
			layout: 'border',
			items: [
				leftPanel,
				this.autoDataPanels
			]
		});

	}
	
});
