/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @version $Id: ReportTemplateODFPDFDialog.js 15897 2013-05-21 09:02:45Z mschering $
 * @copyright Copyright Intermesh
 * @author Merijn Schering <mschering@intermesh.nl>
 */
GO.projects.ReportTemplateODFPDFDialog = function(config){	
	if(!config)
	{
		config={};
	}
	this.buildForm();
	var focusFirstField = function(){
		this.propertiesPanel.items.items[0].focus();
	};
	config.collapsible=true;
	config.maximizable=true;
	config.layout='fit';
	config.modal=false;
	config.resizable=true;
	config.width=700;
	config.height=500;
	config.closeAction='hide';
	config.title= GO.projects.lang.reportTemplate;					
	config.items= this.formPanel;
	config.focus= focusFirstField.createDelegate(this);
	config.buttons=[{
		text: GO.lang['cmdOk'],
		handler: function(){
			this.submitForm(true);
		},
		scope: this
	},{
		text: GO.lang['cmdApply'],
		handler: function(){
			this.submitForm();
		},
		scope:this
	},{
		text: GO.lang['cmdClose'],
		handler: function(){
			this.hide();
		},
		scope:this
	}
	];
	GO.projects.ReportTemplateODFPDFDialog.superclass.constructor.call(this, config);
	this.addEvents({
		'save' : true
	});
}
Ext.extend(GO.projects.ReportTemplateODFPDFDialog, Ext.Window,{
	show : function (report_template_id, config) {
		
		config = config || {};
			
		if(!this.rendered)
		{
			this.render(Ext.getBody());
		}
		this.formPanel.form.reset();
		this.tabPanel.setActiveTab(0);
		if(!report_template_id)
		{
			report_template_id=0;
		}
		this.setReportTemplateId(report_template_id);
		this.setType(config.type);
		
		if(this.report_template_id>0)
		{
			this.formPanel.load({
				url : GO.url(this.basePath+'load'),
				waitMsg:GO.lang['waitMsgLoad'],
				success:function(form, action)
				{
					this.OODownloadButton.setDisabled(!action.result.data.odf_supported);
					//this.selectUser.setRemoteText(action.result.data.user_name);
					GO.projects.ReportTemplateODFPDFDialog.superclass.show.call(this);
				},
				failure:function(form, action)
				{
					GO.errorDialog.show(action.result.feedback)
				},
				scope: this				
			});
		}else 
		{
			GO.projects.ReportTemplateODFPDFDialog.superclass.show.call(this);
		}
	},
	setReportTemplateId : function(report_template_id)
	{
		this.formPanel.form.baseParams['id']=report_template_id;
		this.report_template_id=report_template_id;
		this.reportPagesPanel.setReportTemplateId(report_template_id);
	},
	setType : function (type) {
		this.type = type;
		this.odfPanel.setDisabled(this.type!='odf');
		this.basePath = 'projects/reportTemplate'+this.type.toUpperCase()+'/';
	},
	submitForm : function(hide){
		this.formPanel.form.submit(
		{
			url: GO.url(this.basePath+'submit'), //GO.settings.modules.projects.url+'action.php',
//			params: {
//				'task' : 'save_report_template'
//			},
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action){
				this.uploadFile.clearQueue();
				this.OODownloadButton.setDisabled(!action.result.odf_supported);
				
				if(action.result.report_template_id)
				{
					this.setReportTemplateId(action.result.report_template_id);
				}				
				this.fireEvent('save', this, this.report_template_id);				
				if(hide)
				{
					this.hide();	
				}
			},		
			failure: function(form, action) {
				if(action.failureType == 'client')
				{					
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);			
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope: this
		});		
	},
	buildForm : function () {
		this.propertiesPanel = new Ext.Panel({
			title:GO.lang['strProperties'],			
			cls:'go-form-panel',			
			layout:'form',
			autoScroll:true,
			items:[this.selectUser = new GO.form.SelectUser({
				fieldLabel: GO.lang['strUser'],
				disabled: !GO.settings.modules['projects']['write_permission'],
				value: GO.settings.user_id,
				anchor: '-20'
			}),{
				xtype: 'textfield',
				name: 'name',
				anchor: '-20',
				fieldLabel: GO.lang.strName,
				allowBlank: false
			},{
				xtype:'checkbox',
				name:'no_page_breaks',
				hideLabel:true,
				boxLabel:GO.projects.lang.avoidPageBreaks
			},{
				xtype:'fieldset',
				title:GO.projects.lang.backgroundImage,
				autoHeight:true,
				items:[{
					xtype : 'selectfile',
					name : 'image',
					anchor : '-20',
					fieldLabel : GO.projects.lang.image
				},{
					xtype : 'numberfield',
					name : 'img_top',
					width:40,
					fieldLabel : GO.projects.lang.top
				},{
					xtype : 'numberfield',
					name : 'img_left',
					width:40,
					fieldLabel : GO.projects.lang.left
				},{
					xtype : 'numberfield',
					name : 'img_width',
					width:40,
					fieldLabel : GO.projects.lang.width
				},{
					xtype : 'numberfield',
					name : 'img_height',
					width:40,
					fieldLabel : GO.projects.lang.height
				}]
			},{
				xtype:'fieldset',
				title:GO.projects.lang.margins,
				autoHeight:true,
				items:[{
					xtype : 'numberfield',
					name : 't_margin',
					width:40,
					fieldLabel : GO.projects.lang.top,
					allowDecimals: false
				},{
					xtype : 'numberfield',
					name : 'l_margin',
					width:40,
					fieldLabel : GO.projects.lang.left,
					allowDecimals: false
				},{
					xtype : 'numberfield',
					name : 'r_margin',
					width:40,
					fieldLabel : GO.projects.lang.right,
					allowDecimals: false
				},{
					xtype : 'numberfield',
					name : 'b_margin',
					width:40,
					fieldLabel : GO.projects.lang.bottom,
					allowDecimals: false
				}]
			},{
				xtype:'textarea',
				name:'header',
				anchor:'100%',
				fieldLabel:GO.projects.lang.header
			},{
				xtype:'textarea',
				name:'footer',
				anchor:'100%',
				fieldLabel:GO.projects.lang.footer
			}]
		});



		if(GO.customfields && GO.customfields.types["14"])
		{
			var cfFieldset = new Ext.form.FieldSet({
				autoHeight:true,
				title:GO.customfields.lang.customfields
			});
			for(var i=0;i<GO.customfields.types["14"].panels.length;i++)
			{
				cfFieldset.add({
					xtype:'checkbox',
					name:'fields[cf_category_'+GO.customfields.types["14"].panels[i].category_id+']',
					hideLabel: true,
					boxLabel:GO.customfields.types["14"].panels[i].title
				});
			}
			this.propertiesPanel.add(cfFieldset);
		}

		this.reportPagesPanel = new GO.projects.ReportPagesGrid();


		this.finalPagePanel = new Ext.Panel({
			//disabled:true,
			layout:'form',
			labelAlign:'top',
			title:'Final page',
			bodyStyle:'padding:5px',
			items:[{
				fieldLabel:'This template will only be used in batch mode with a query or on subprojects. On this page you can use labels for all numerical custom fields. They will show the total numbers of the report.',
				xtype:'textarea',
				anchor:'100% 100%',
				name:'final_page_template'
			}]
		});


		this.odfPanel = new Ext.Panel({
			border: false,
			title:'ODF report',
			cls:'go-form-panel',
			layout:'form',
			autoScroll:true,
			items:[
			this.uploadFile = new GO.form.UploadFile({
				inputName : 'file',
				max: 1
			}),
			new GO.form.HtmlComponent({
				html:'<br />'
			}),
			this.OODownloadButton = new Ext.Button({
				handler:  function()
				{
					window.open(GO.url('projects/reportTemplateODF/downloadODFReportTemplate&report_template_id=' + this.report_template_id));
				},
				disabled: true,
				text: GO.lang.download,
				scope: this
			})]

		});

		var items  = [this.propertiesPanel, this.reportPagesPanel, this.finalPagePanel, this.odfPanel];
		this.tabPanel = new Ext.TabPanel({
			activeTab: 0,
			deferredRender: false,
			border: false,
			items: items,
			anchor: '100% 100%'
		});
		this.formPanel = new Ext.form.FormPanel({
			fileUpload:true,
			waitMsgTarget:true,
			url: GO.settings.modules.projects.url+'action.php',
			border: false,
			baseParams: {},
			items:this.tabPanel				
		});   
	}
});
