/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @version $Id: ReportTemplatesGrid.js 15897 2013-05-21 09:02:45Z mschering $
 * @copyright Copyright Intermesh
 * @author Merijn Schering <mschering@intermesh.nl>
 */
GO.projects.ReportTemplatesGrid = function(config){
	if(!config)
	{
		config = {};
	}
	config.title = GO.projects.lang.reportTemplates;
	config.layout='fit';
	config.autoScroll=true;
	config.split=true;

	config.store = GO.projects.reportTemplatesStore;
	config.paging=true;
	var columnModel =  new Ext.grid.ColumnModel({
		defaults:{
			sortable:true
		},
		columns:[{
			header: GO.lang.strName,
			dataIndex: 'name'
		},{
			header:GO.lang.strType,
			dataIndex: 'type',
			sortable:true,
			width:50
		}]
	});
	
	config.cm=columnModel;
	config.view=new Ext.grid.GridView({
		autoFill: true,
		forceFit: true,
		emptyText: GO.lang['strNoItems']		
	});
	config.sm=new Ext.grid.RowSelectionModel();
	config.loadMask=true;
	
	config.tbar=[{
			iconCls: 'btn-add',							
			text: GO.projects.lang['addPDFTemplate'],
			cls: 'x-btn-text-icon',
			handler: function() {
	    	this.showReportTemplateODFPDFDialog(0,{type:'pdf'});
			},
			scope: this
		},{
			iconCls: 'btn-add',							
			text: GO.projects.lang['addODFTemplate'],
			cls: 'x-btn-text-icon',
			handler: function() {
	    	this.showReportTemplateODFPDFDialog(0,{type:'odf'});
			},
			scope: this
		},{
			iconCls: 'btn-add',							
			text: GO.projects.lang['addCSVTemplate'],
			cls: 'x-btn-text-icon',
			handler: function(){
	    	this.showReportTemplateCSVDialog();
			},
			scope: this
		},{
			iconCls: 'btn-delete',
			text: GO.lang['cmdDelete'],
			cls: 'x-btn-text-icon',
			handler: function(){
				this.deleteSelected();
			},
			scope: this
		}];

	config.listeners={
		render:function(){
			if(!this.store.loaded)
				this.store.load();	
		},
		scope:this
	};
	
	GO.projects.ReportTemplatesGrid.superclass.constructor.call(this, config);
	this.on('rowdblclick', function(grid, rowIndex){
		var record = grid.getStore().getAt(rowIndex);
		if (record.data.type=='csv') {
			this.showReportTemplateCSVDialog(record.data.id,{type: 'csv'});
		} else {
			this.showReportTemplateODFPDFDialog(record.data.id, {type: record.data.type});
		}
	}, this);
};
Ext.extend(GO.projects.ReportTemplatesGrid, GO.grid.GridPanel,{
	showReportTemplateODFPDFDialog : function(report_template_id,config){
		if(!this.reportTemplateODFPDFDialog){
			this.reportTemplateODFPDFDialog = new GO.projects.ReportTemplateODFPDFDialog();
			this.reportTemplateODFPDFDialog.on('save', function(){
				this.store.reload();
			}, this);
		}
		this.reportTemplateODFPDFDialog.show(report_template_id,config);
	},
	showReportTemplateCSVDialog : function(report_template_id,config){
		if(!this.reportTemplateCSVDialog){
			this.reportTemplateCSVDialog = new GO.projects.ReportTemplateCSVDialog();
			this.reportTemplateCSVDialog.on('save', function(){
				this.store.reload();
			}, this);
		}
		this.reportTemplateCSVDialog.show(report_template_id,config);
	}
});
