/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @version $Id: SettingsDialog.js 17092 2013-10-17 13:21:23Z mschering $
 * @copyright Copyright Intermesh
 * @author Merijn Schering <mschering@intermesh.nl>
 */
 
GO.projects.SettingsDialog = function(config){
	
	if(!config)
	{
		config={};
	}

	this.statusesPanel = new GO.projects.StatusesGrid({
		title:GO.projects.lang.statuses,
		layout:'fit'
	});
		
	this.typesPanel = new GO.projects.TypesGrid({
		title:GO.projects.lang.types,
		layout:'fit'
	});
		
	this.templatesPanel = new GO.projects.TemplatesGrid({
		title:GO.projects.lang.templates,
		layout:'fit'
	});

	this.reportTemplatesPanel = new GO.projects.ReportTemplatesGrid({
		title:GO.projects.lang.reportTemplates,
		layout:'fit'
	});
	
	this.rootFolder = new GO.grid.PermissionsPanel({
		title: GO.projects.lang['rootFolder'],
		levels:[
			GO.permissionLevels.manage
		],
		hideLevel: true,
		addLevel: GO.permissionLevels.manage
	});

	this.followNumberPanel = new Ext.FormPanel({
		title: GO.projects.lang.followNumbers,
		waitMsgTarget:true,
		style:'margin:5px',
		items:[{
						fieldLabel: GO.projects.lang.enableFollowNumber,
						name: 'chkCustomId',
						xtype:'checkbox',
						labelStyle:'margin:5px'
					}, {
						fieldLabel: GO.projects.lang.followNumberFormat,
						name: 'customId',
						xtype:'textfield',
						labelStyle:'margin:5px'
					}],
		autoScroll:true,
		listeners:{
			render:function(){
					this.followNumberPanel.form.load({
						url: GO.settings.modules.projects.url+'json.php',
						params: {
							task: 'get_settings_data'
						},
						success : function (one, data) {
							var jsonData = Ext.decode(data.response.responseText);
							this.rootFolder.setAcl(jsonData.data.rootFolderAcl);
						},
						scope: this
					});
			},
			scope:this
		}
	});

	this.settingsPanel = new Ext.Panel({
			title: GO.projects.lang.settings,
			layout: 'form',
			autoScroll:true,
			items: [
				this.followNumberPanel
			]
		})

	

	this.expenseTypesGrid = new GO.projects.ExpenseTypes({
	});
	this.incomeTypesGrid = new GO.projects.IncomeTypes({
	});


	
	var items=[
	this.settingsPanel,
	this.typesPanel,
	this.templatesPanel,
	this.statusesPanel,
	this.reportTemplatesPanel,
	this.expenseTypesGrid,
	this.incomeTypesGrid
	];
	
	if(GO.settings.modules.timeregistration){
		this.feesPanel = new GO.projects.FeesGrid({
			title:GO.projects.lang.specialFees,
			layout:'fit',
			tabTip:GO.projects.lang.tooltipSpecialFees
		});

		this.userFeesPanel = new GO.projects.ProjectFeesPanel({
			title:GO.projects.lang.userFees,
			tabTip:GO.projects.lang.tooltipDefaultFees,
			listeners:{
				render:function(){
					if(!this.store.loaded)
						this.store.load();
				},
				scope:this.userFeesPanel
			}
		});

		items.push(this.userFeesPanel,this.feesPanel);
	}
	
	items.push(this.rootFolder);

	config.layout='fit';
	config.modal=false;
	config.resizable=true;
	config.width=900;
	config.height=500;
	config.closeAction='hide';
	config.title= GO.lang.cmdSettings;

	config.items=this.tabPanel = new Ext.TabPanel({
		activeTab: 0,      
		border:false,
		deferredRender: true,
		enableTabScroll:true,
		items:items
	});
	
	config.buttons=[{
		text: GO.lang.cmdOk,
		handler: function(){
			this.save();
			this.hide();
		},
		scope:this
	},{
		text: GO.lang.cmdClose,
		handler: function(){
			this.hide();
		},
		scope:this
	}];
	
	GO.projects.SettingsDialog.superclass.constructor.call(this, config);	
	
	
}
Ext.extend(GO.projects.SettingsDialog, GO.Window,{
	show : function(){
		GO.projects.SettingsDialog.superclass.show.call(this);

	
	},
	save : function(){		
		var params = {
//			'task' : 'save_settings',
			
			project_id : null,
			userFees : '[]',
			fees : '[]'
		}
		
		if(this.incomeTypesGrid.store.loaded)
			params.incomeTypes = Ext.encode(this.incomeTypesGrid.getGridData());
		
		if(this.expenseTypesGrid.store.loaded)
			params.expenseTypes = Ext.encode(this.expenseTypesGrid.getGridData());
			
		if (GO.settings.modules.timeregistration && this.userFeesPanel.store.loaded) {
			params.id = this.userFeesPanel.store.baseParams.project_id;			
			params.userFees = Ext.encode(this.userFeesPanel.getGridData());
			params.fees = Ext.encode(this.feesPanel.getGridData());
		}
		
		this.followNumberPanel.form.submit(
		{
			url: GO.url('projects/settings/submit'),//GO.settings.modules.projects.url+'action.php',
			params: params,
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action){

				GO.projects.nameTemplate = action.result.new_name_template;
				GO.projects.useNameTemplate = action.result.use_name_template;
				
				if(action.result.newincomeTypes)
					this.incomeTypesGrid.setIds(action.result.newincomeTypes);
				
				if(action.result.newexpenseTypes)
					this.expenseTypesGrid.setIds(action.result.newexpenseTypes);

				this.fireEvent('save', this);

			},
			failure: function(form, action) {
				if(action.failureType == 'client')
				{
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope: this
		});
	}
});