/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @version $Id: TemplateEventDialog.js 15897 2013-05-21 09:02:45Z mschering $
 * @copyright Copyright Intermesh
 * @author Merijn Schering <mschering@intermesh.nl>
 */
GO.projects.TemplateEventDialog = function(config){	
	if(!config)
	{
		config={};
	}
	this.buildForm();
	var focusFirstField = function(){
		this.formPanel.items.items[0].focus();
	};
	config.collapsible=true;
	config.maximizable=true;
	config.layout='fit';
	config.modal=false;
	config.resizable=false;
	config.width=700;
	config.height=500;
	config.closeAction='hide';
	config.title= GO.projects.lang.templateEvent;					
	config.items= this.formPanel;
	config.focus= focusFirstField.createDelegate(this);
	config.buttons=[{
		text: GO.lang['cmdOk'],
		handler: function(){
			this.submitForm(true);
		},
		scope: this
	},{
		text: GO.lang['cmdApply'],
		handler: function(){
			this.submitForm();
		},
		scope:this
	},{
		text: GO.lang['cmdClose'],
		handler: function(){
			this.hide();
		},
		scope:this
	}
	];
	GO.projects.TemplateEventDialog.superclass.constructor.call(this, config);
	this.addEvents({
		'save' : true
	});
}
Ext.extend(GO.projects.TemplateEventDialog, Ext.Window,{
	show : function (template_event_id) {
		if(!this.templateCombo.store.loaded){
			this.templateCombo.store.load({
				callback:function(){
					this.show(template_event_id);
				},
				scope:this
			});
			return false;
		}

		if(!this.rendered)
		{
			this.render(Ext.getBody());
		}

		//delete this.formPanel.baseParams.template_id;

		this.formPanel.form.reset();
		
		if(!template_event_id)
		{
			template_event_id=0;			
		}
		this.setTemplateEventId(template_event_id);
		if(this.template_event_id>0)
		{
			this.formPanel.load({
				url : GO.url('projects/templateEvent/load'),
				waitMsg:GO.lang['waitMsgLoad'],
				success:function(form, action)
				{					
					GO.projects.TemplateEventDialog.superclass.show.call(this);
					
					this.formPanel.baseParams.template_id=action.result.data.template_id;
					this.templateCombo.setDisabled(action.result.data.type!='project');

					GO.dialog.TabbedFormDialog.prototype.setRemoteComboTexts.call(this, action);
				},
				failure:function(form, action)
				{
					GO.errorDialog.show(action.result.feedback)
				},
				scope: this				
			});
		}else 
		{
			this.templateCombo.setDisabled(false);
			GO.projects.TemplateEventDialog.superclass.show.call(this);
		}

	//console.log(this.formPanel.baseParams);
	},
	setTemplateEventId : function(template_event_id)
	{
		this.formPanel.baseParams['id']=template_event_id;
		this.template_event_id=template_event_id;
	},
	submitForm : function(hide){
		this.formPanel.form.submit(
		{
			url: GO.url('projects/templateEvent/submit'),
			params: {
//				'task' : 'save_template_event'
			},
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action){
				if(action.result.template_event_id)
				{
					this.setTemplateEventId(action.result.template_event_id);
				}				
				this.fireEvent('save', this, this.template_event_id);				
				if(hide)
				{
					this.hide();	
				}
			},		
			failure: function(form, action) {
				if(action.failureType == 'client')
				{					
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);			
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope: this
		});		
	},
	buildForm : function () {

		var data = [['project', GO.projects.lang.project]];

		if(GO.tasks)
		{
			data.push(['task', GO.tasks.lang.task]);
		}

		/*if(GO.calendar)
		{
			data.push(['event', GO.calendar.lang.appointment]);
		}*/

		var typeField = new Ext.form.ComboBox({
			fieldLabel : GO.lang.strType,
			hiddenName : 'type',
			store : new Ext.data.SimpleStore({
				fields : ['value', 'text'],
				data : data

			}),
			value : 'project',
			valueField : 'value',
			displayField : 'text',
			mode : 'local',
			triggerAction : 'all',
			editable : false,
			selectOnFocus : true,
			forceSelection : true,
			anchor: '-20',
			listeners:{
				change: function(cb, newV){
					this.templateCombo.setDisabled(newV!='project');
				},
				scope:this
			}
		});


		this.formPanel = new Ext.form.FormPanel({
			waitMsgTarget:true,
			url: GO.url('projects/templateEvent/submit'),
			border: false,
			baseParams: {
//				task: 'template_event',
				template_id:0
			},
			//title:GO.lang['strProperties'],
			cls:'go-form-panel',			
			layout:'form',
			autoScroll:true,
			items:[{
				xtype: 'textfield',
				name: 'name',
				anchor: '-20',
				fieldLabel: GO.lang.strName
			},
			this.selectUser = new GO.form.SelectUser({
				fieldLabel:GO.projects.lang.projectManager,
				anchor:'-20',
				allowBlank:true
			}),{
				xtype: 'textarea',
				name: 'description',
				anchor: '-20',
				fieldLabel: GO.lang.strDescription
			}
			,{
				xtype: 'numberfield',
				name: 'time_offset',
				anchor: '-20',
				fieldLabel: GO.projects.lang.timeOffset
			}
			,{
				xtype: 'numberfield',
				name: 'duration',
				anchor: '-20',
				fieldLabel: GO.projects.lang.duration
			}
			,typeField,
			this.templateCombo =  new GO.form.ComboBox({
				xtype: 'combo',
				store:GO.projects.templatesStore,
				name:'new_template_name',
				hiddenName: 'new_template_id',
				anchor: '-20',
				fieldLabel: GO.projects.lang.template,
				mode:'local',
				triggerAction:'all',
				forceSelection:true,
				displayField:'name',
				valueField:'id',
				allowBlank:false
			})
			]
		});
	}
});
