
GO.projects.TemplateTabs = function(config){

	config = config || {};

	config.title=GO.projects.lang.customTabs;
	config.layout='columnfit';

	//available custom fields tree
	this.cfTree = new Ext.tree.TreePanel({
		animate:true,
		autoScroll:true,
		loader: new GO.base.tree.TreeLoader({
			dataUrl:GO.url('projects/template/availableCustomFields'),
			baseParams:{
				id:0
			}
		}),
		enableDrag:true,
		containerScroll: true,
		border: false,
		columnWidth:.5
	});

	// set the root node
	this.cfRoot = new Ext.tree.AsyncTreeNode({
		text: GO.projects.lang.availableCustomFields,			
		draggable:false, // disable root node dragging
		id:'c_root',
		iconCls:'folder-default'
	});
	this.cfTree.setRootNode(this.cfRoot);


	//template tabs tree
	this.ttTree = new Ext.tree.TreePanel({
		
		autoScroll:true,
		loader: new GO.base.tree.TreeLoader({
			dataUrl:GO.settings.modules.projects.url+'json.php',
			baseParams:{
				task:'template_tabs'
			}
		}),
		enableDD:true,
		containerScroll: true,
		border: false,
		columnWidth:.5,
		listeners:{
			scope:this,
			nodedragover:function(e){

				var target = e.point!='append' ? e.target.parentNode : e.target;
				
				//Only allow drop on tab nodes
				if(target.id.substring(0,1)!='t')
					return false;

				if(e.dropNode.id.substring(0,1)=='c'){
					//category may only be dropped at the root.
					if(target.id!='t_root')
						return false;
				}else
				{
					//field may not be dropped at the root
					if(target.id=='t_root')
						return false;
				}
			},
			nodedrop:function(e)
			{
				var target = e.point!='append' ? e.target.parentNode : e.target;

				this.addCustomFields(e.dropNode,target);				
			}
		}

	});


	// set the root node
	this.ttRoot = new Ext.tree.AsyncTreeNode({
		text: GO.projects.lang.customTabs,
		draggable:false, // disable root node dragging
		id:'t_root',
		iconCls:'folder-default'
	});
	this.ttTree.setRootNode(this.ttRoot);

	this.treeEditor = new Ext.tree.TreeEditor(
		this.ttTree,
		new Ext.form.Field({
			cancelOnEsc:true,
			completeOnEnter:true
		}),
		{
			listeners:{
				complete  : this.rename,
				beforecomplete  : function( editor, value, startValue){
					value=value.trim();
					if(GO.util.empty(value)){
						editor.focus();
						return false;
					}
				},
				scope:this
			}
		});
	
	config.items=[this.ttTree,this.cfTree];

	config.tbar=[{
			text:GO.lang.cmdAdd,
			handler:function(){
				var newNode = new Ext.tree.AsyncTreeNode({
					text: '',
					id: 'c_0',
					expanded:true,
					children:[],
					iconCls:'folder-default'
				});

				newNode = this.ttRoot.appendChild(newNode);

				this.treeEditor.triggerEdit(newNode);
			},
			scope:this,
			iconCls:'btn-add'
		},'-',
		{
			text:GO.lang.cmdDelete,
			iconCls:'btn-delete',
			handler:function(){
				var node = this.ttTree.selModel.getSelectedNode();
				if(!node)
				{
					alert(GO.lang.noItemSelected);
					return false;
				}
				Ext.Ajax.request({
					url:GO.settings.modules.projects.url+'action.php',
					params:{
						task:'delete_custom_fields',
						template_id:this.ttTree.loader.baseParams.template_id,												
						tt_id:node.id
					},
					success: function(response, options)
					{
						var responseParams = Ext.decode(response.responseText);
						if(!responseParams.success)
						{
							this.reload();
							alert(responseParams.feedback);
						}else
						{
							node.destroy();
							this.cfRoot.reload();
						}
					},
					scope:this
				});
			},
			scope:this
		}/*,
		{
		text:'Reload',
		handler:this.reload,
		scope:this
	}*/]

	config.listeners={
		scope:this,
		show:function(){
			
			if(this.ttRoot.isExpanded()){
				this.ttRoot.reload();
				this.cfRoot.reload();
			}else
			{
				this.ttRoot.expand();
				this.cfRoot.expand();
			}
		}
	}

	GO.projects.TemplateTabs.superclass.constructor.call(this, config);
}

Ext.extend(GO.projects.TemplateTabs, Ext.Panel,{
	reload : function(){
		this.cfRoot.reload();
		this.ttRoot.reload();
	},

	rename : function(editor, text, oldText ){
		var idArr = editor.editNode.id.split('_');

		Ext.Ajax.request({
			url:GO.settings.modules.projects.url+'action.php',
			params:{
				task:'save_template_tab',
				template_tab_id:idArr[1],
				template_id:this.ttTree.loader.baseParams.template_id,
				name:text
			},
			success: function(response, options)
			{
				var responseParams = Ext.decode(response.responseText);
				if(!responseParams.success)
				{
					if(idArr[1]=='0')
						editor.editNode.destroy();
					
					alert(responseParams.feedback);
				}

				if(responseParams.template_tab_id)
					editor.editNode.id='t_'+responseParams.template_tab_id;
			},
			scope:this
		});
	},


	addCustomFields : function (cfNode, tabNode){

		var sortOrder = [];

	  for(var i=0;i<tabNode.childNodes.length;i++)
	  {	  	
	  	sortOrder.push(tabNode.childNodes[i].id);
	  };

		Ext.Ajax.request({
			url:GO.settings.modules.projects.url+'action.php',
			params:{
				task:'add_custom_fields',				
				template_id:this.ttTree.loader.baseParams.template_id,
				sort_order:Ext.encode(sortOrder),
				cf_id:cfNode.id,
				tt_id:tabNode.id
			},
			success: function(response, options)
			{
				var responseParams = Ext.decode(response.responseText);
				if(!responseParams.success)
				{
					this.reload();
					alert(responseParams.feedback);
				}

				if(responseParams.template_tab_id)
					cfNode.id='f_'+responseParams.template_tab_id;
			},
			scope:this
		});

	},
	setTemplateID : function(template_id){
		this.ttTree.loader.baseParams.template_id=template_id;
		this.cfTree.loader.baseParams.id=template_id;

		this.setDisabled(template_id<1);
	}
	
});