/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @version $Id: TypeDialog.js 16620 2013-08-19 14:38:09Z mschering $
 * @copyright Copyright Intermesh
 * @author Merijn Schering <mschering@intermesh.nl>
 */
GO.projects.TypeDialog = function(config){
	if(!config)
	{
		config={};
	}
	this.buildForm();
	var focusFirstField = function(){
		this.propertiesPanel.items.items[0].focus();
	};
	config.collapsible=true;
	config.maximizable=true;
	config.layout='fit';
	config.modal=false;
	config.resizable=false;
	config.width=700;
	config.height=600;
	config.closeAction='hide';
	config.title= GO.projects.lang.type;					
	config.items= this.formPanel;
	config.focus= focusFirstField.createDelegate(this);
	config.buttons=[{
			text: GO.lang['cmdOk'],
			handler: function(){
				this.submitForm(true);
			},
			scope: this
		},{
			text: GO.lang['cmdApply'],
			handler: function(){
				this.submitForm();
			},
			scope:this
		},{
			text: GO.lang['cmdClose'],
			handler: function(){
				this.hide();
			},
			scope:this
		}					
	];
	GO.projects.TypeDialog.superclass.constructor.call(this, config);
	this.addEvents({'save' : true});	
}
Ext.extend(GO.projects.TypeDialog, Ext.Window,{
	show : function (type_id, config) {
		if(!this.rendered)
		{
			this.render(Ext.getBody());
		}
		this.tabPanel.setActiveTab(0);
		if(!type_id)
		{
			type_id=0;			
		}
		this.setTypeId(type_id);
		if(this.type_id>0)
		{
			this.formPanel.load({
				url : GO.url('projects/type/load'),
				waitMsg:GO.lang['waitMsgLoad'],
				success:function(form, action)
				{
					this.readPermissionsTab.setAcl(action.result.data.acl_id);
					this.bookPermissionsTab.setAcl(action.result.data.acl_book);
					
					GO.projects.TypeDialog.superclass.show.call(this);
				},
				failure:function(form, action)
				{
					GO.errorDialog.show(action.result.feedback)
				},
				scope: this
			});
		}else 
		{
			this.formPanel.form.reset();
			this.readPermissionsTab.setAcl(0);
			this.bookPermissionsTab.setAcl(0);
			
			GO.projects.TypeDialog.superclass.show.call(this);
		}
	},

	setTypeId : function(type_id)
	{
		this.formPanel.form.baseParams['id']=type_id;
		this.type_id=type_id;
	},
	submitForm : function(hide){
		this.formPanel.form.submit(
		{
			url : GO.url('projects/type/submit'),
//			params: {'task' : 'save_type'},
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action){
				this.fireEvent('save', this);
				if(hide)
				{
					this.hide();	
				}else
				{
					if(action.result.id)
					{
						this.setTypeId(action.result.id);
						this.readPermissionsTab.setDisabled(false);
						this.bookPermissionsTab.setDisabled(false);
						this.readPermissionsTab.setAcl(action.result.acl_id);
						this.bookPermissionsTab.setAcl(action.result.acl_book);
					}
				}
			},		
			failure: function(form, action) {
				if(action.failureType == 'client')
				{					
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);			
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope: this
		});
	},
	buildForm : function () {
		this.propertiesPanel = new Ext.Panel({
			title:GO.lang['strProperties'],			
			cls:'go-form-panel',			
			layout:'form',
			autoScroll:true,
			items:[{
				xtype: 'textfield',
			  name: 'name',
				anchor: '-20',
			  fieldLabel: GO.lang.strName,
			  allowBlank:false
			}]
		});
		var items  = [this.propertiesPanel];
    this.readPermissionsTab = new GO.grid.PermissionsPanel({
			
		});

		this.bookPermissionsTab = new GO.grid.PermissionsPanel({
			title: GO.projects.lang.bookPermission
		});
		
    items.push(this.readPermissionsTab);
    items.push(this.bookPermissionsTab);
    
    this.tabPanel = new Ext.TabPanel({
      activeTab: 0,      
      deferredRender: false,
    	border: false,
      items: items,
      anchor: '100% 100%'
    }) ;    
    this.formPanel = new Ext.form.FormPanel({
	    waitMsgTarget:true,
			url: GO.url('projects/type/load'),
			border: false,
			baseParams: {},				
			items:this.tabPanel				
		});
	}
});
