<?php

/*
 * Copyright Intermesh BV
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 */

/**
 * Generated PDF document for project milestones
 *
 * @package GO.projects2.report
 * @copyright Copyright Intermesh
 * @version $Id: TimeTrackingCsv.php 18489 2014-03-10 12:45:20Z mschering $ 
 * @author Merijn Schering <mschering@intermesh.nl>
 */
class GO_Projects2_Report_TimeTrackingCsv extends GO_Projects2_Report_Abstract {

	

	public function name() {
		return GO::t('timeEntries','projects2');
	}
	
	public function supportsBatchReport() {
		return true;
	}
	
	public function supportsSelectedProject() {
		return true;
	}
	
	public function supportedProjectTypes() {
		return array(GO_Projects2_Model_Template::PROJECT_TYPE_CONTAINER, GO_Projects2_Model_Template::PROJECT_TYPE_PROJECT);
	}
	
	public function supportsDateRange() {
		return true;
	}

	public function fileExtension() {
		return 'csv';
	}

	public function render($return = false) {


		$fp = GO_Base_Db_FindParams::newInstance()
						->ignoreAcl()
						->select('t.*')
						->joinRelation('user');
		
		if(isset($this->startDate))
			$fp->getCriteria()->addCondition('date', $this->startDate,'>=','t');
		
		if(isset($this->endDate))
			$fp->getCriteria()->addCondition('date', $this->endDate,'<','t');
		
		
			
		//query all subprojects of given path
		if($this->project){	
			$fp->getCriteria()->addRawCondition('t.project_id', "(SELECT id FROM pr2_projects WHERE path LIKE :path OR project_id = :project_id)",'IN');
			$fp->getCriteria()->addBindParameter(':path', $this->project->path.'/%');	
			$fp->getCriteria()->addBindParameter(':project_id', $this->project->id);				
		} 

		$stmt = GO_Projects2_Model_TimeEntry::model()->find($fp);
		
		
		$csvFile = GO_Base_Fs_CsvFile::tempFile($this->filename, $this->fileExtension());
		
		
		$attributes = array(			
			'user.name',
			'date',
			'comments',
			'project.path',
			'internal_fee',
			'external_fee',
			'units',
			'travel_distance',
			'travel_costs',
		);
		
		$csvFile->putRecord($attributes);
		
		GO_Projects2_Model_TimeEntry::$attributeOutputMode='formatted';
		
		foreach($stmt as $timeEntry){
			
			$record = array();
			foreach($attributes as $attr){
				
				$relations = explode('.', $attr);
				
				$attrName = array_pop($relations);
				
				$model = $timeEntry;
				foreach($relations as $relation){
					$model = $model->$relation;
				}
				
				$value=$model->$attrName;
				
				//strip current project path from all children
				if($this->project && $attrName=='path'){
					$value = substr($value, strlen(dirname($this->project->path))+1);
				}
				
				$record[]=$value;
			}
			
			$csvFile->putRecord($record);
		}
		
		if($return){
			return $csvFile->getContents();
		}else
		{
			GO_Base_Util_Http::outputDownloadHeaders($csvFile, false);
			$csvFile->output();
		}
	}
	

}
