/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @version $Id: SettingsDialog.js 15897 2013-05-21 09:02:45Z mschering $
 * @copyright Copyright Intermesh
 * @author Merijn Schering <mschering@intermesh.nl>
 */

GO.timeregistration.SettingsDialog = function(config){
	if(!config)
	{
		config={};
	}

	this.formPanel = new Ext.form.FormPanel({
		border:false,
		title:GO.lang.cmdSettings,
		bodyStyle:'padding:5px',
		waitMsgTarget:true,
		labelAlign:'top',
		autoHeight:true,
		items:[{
			xtype: 'radiogroup',
				
			fieldLabel:GO.timeregistration.lang.timeregistrationMode,
			itemCls: 'x-check-group-alt',
			columns: 1,
			items: [
			this.gridCheck = new Ext.form.Radio({
				boxLabel: GO.timeregistration.lang.gridMode,
				name: 'mode',
				inputValue: 'grid',
				checked: GO.timeregistration.mode=='grid'
			}),
			this.multipleCheck = new Ext.form.Radio({
				boxLabel: GO.timeregistration.lang.multipleMode,
				name: 'mode',
				inputValue: 'multiple',
				checked:GO.timeregistration.mode=='multiple'
			})]
		},new Ext.form.ComboBox({
			fieldLabel : GO.timeregistration.lang.roundMinutes,
			hiddenName : 'roundMinutes',
			triggerAction : 'all',
			editable : false,
			selectOnFocus : true,
			width : 148,
			forceSelection : true,
			mode : 'local',
			value : GO.timeregistration.roundMinutes,
			valueField : 'value',
			displayField : 'text',
			store : new Ext.data.SimpleStore({
				fields : ['value', 'text'],
				data : [ [0, GO.timeregistration.lang.noRound],
				[5, '5 '+GO.timeregistration.lang.minutes],
				[6, '6 '+GO.timeregistration.lang.minutes],
				[10, '10 '+GO.timeregistration.lang.minutes],
				[15, '15 '+GO.timeregistration.lang.minutes],
				[20, '20 '+GO.timeregistration.lang.minutes],
				[30, '30 '+GO.timeregistration.lang.minutes] ]
			})
		}),{
			hideLabel:true,
			xtype:'checkbox',
			boxLabel: GO.timeregistration.lang.roundUp,
			checked:GO.timeregistration.roundUp=='1',
			name:'roundUp'
		},{
			hideLabel:true,
			xtype:'checkbox',
			boxLabel: GO.timeregistration.lang.showTimeregistrationFees,
			checked:GO.timeregistration.show_timeregistration_fees=='1',
			name:'show_timeregistration_fees'
		}]
	});

	this.standardTaskGrid = new GO.timeregistration.StandardTasksGrid({
				});
	
	this.globallySetStatusesPanel = new GO.timeregistration.GloballySetStatusesPanel();
	
	this.tabPanel = new Ext.TabPanel({
		activeItem:0,
		items:[
			this.formPanel,
			this.standardTaskGrid,
			this.globallySetStatusesPanel
		]
	});


	config.layout='fit';
	config.modal=false;
	config.resizable=false;
	config.width=700;
	config.height=500;
	config.autoHeight=false;
	config.closeAction='hide';
	config.title= GO.lang.administration;
	config.items=this.tabPanel;
	config.buttons=[{
		text: GO.lang.cmdOk,
		handler: function(){
			this.submitForm(true);
			if (!GO.util.empty(this.globallySetStatusesPanel))
				this.globallySetStatusesPanel.globallyApplyFilterSettings();
		},
		scope:this
	},{
		text: GO.lang.cmdClose,
		handler: function(){
			this.hide();
		},
		scope:this
	}];

	GO.timeregistration.SettingsDialog.superclass.constructor.call(this, config);
		
	this.on('show',function() {
		if (!GO.util.empty(this.globallySetStatusesPanel))
			this.globallySetStatusesPanel.globallySetStatusFiltersGrid.store.load();
	},this);
	
}
Ext.extend(GO.timeregistration.SettingsDialog, Ext.Window,{

	submitForm : function(hide){
		this.formPanel.form.submit(
		{
			url:GO.settings.modules.timeregistration.url+'action.php',
			params: {
				'task' : 'save_settings'
			},
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action){
				document.location=GO.settings.config.host;
			},
			failure: function(form, action) {
				if(action.failureType == 'client')
				{
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope: this
		});
	}
});