/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @version $Id: StandardTaskDialog.js 15897 2013-05-21 09:02:45Z mschering $
 * @copyright Copyright Intermesh
 * @author Wesley Smits <wsmits@intermesh.nl>
 */
GO.timeregistration.StandardTaskDialog = function(config){

	if(!config)
	{
		config={};
	}

	this.buildForm();

	var focusFirstField = function(){
		this.standardTaskPanel.items.items[0].focus();
	};

	config.maximizable=true;
	config.layout='fit';
	config.modal=false;
	config.resizable=false;
	config.width=300;
	config.height=250;
	config.closeAction='hide';
	config.title= GO.timeregistration.lang.newStandardTask;
	config.items= this.formPanel;
	config.focus= focusFirstField.createDelegate(this);
	config.buttons=[{
			text: GO.lang['cmdOk'],
			handler: function(){
				this.submitForm(true);
			},
			scope: this
		},{
			text: GO.lang['cmdClose'],
			handler: function(){
				this.hide();
			},
			scope:this
		}
	];

	/*
	 * explicitly call the superclass constructor
	 */
	GO.timeregistration.StandardTaskDialog.superclass.constructor.call(this, config);

	this.addEvents({'save' : true});

}


/*
 * Extend the base class
 */
Ext.extend(GO.timeregistration.StandardTaskDialog, GO.Window,{

	show : function (standard_task_id){

		this.setStandardTaskId(standard_task_id);

		if(!this.rendered)
			this.render(Ext.getBody());
		
		GO.timeregistration.StandardTaskDialog.superclass.show.call(this);
	},

	setStandardTaskId : function(standard_task_id){

		this.formPanel.form.reset();

		this.formPanel.baseParams.standard_task_id=standard_task_id;

		if(standard_task_id>0)
		{		
			this.formPanel.load({
				url : GO.settings.modules.timeregistration.url+'json.php',
				params: {task: 'standard_task'},
				success:function(form, action)
				{					
					GO.timeregistration.StandardTaskDialog.superclass.show.call(this);
				},
				failure:function(form, action)
				{
					GO.errorDialog.show(action.result.feedback)
				},
				scope: this
			});
		}
		else
		{
			GO.timeregistration.StandardTaskDialog.superclass.show.call(this);
		}
	},

	submitForm : function(hide){
		this.formPanel.form.submit(
		{
			url:GO.settings.modules.timeregistration.url+'action.php',
			params: {'task' : 'save_standard_task'},
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action){
				this.fireEvent('save', this);

				if(hide)
				{
					this.hide();
				}
			},
			failure: function(form, action) {
				if(action.failureType == 'client')
				{
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope: this
		});
	},

	buildForm : function () {

		this.standardTaskPanel = new Ext.Panel({
			border: false,
			cls:'go-form-panel',waitMsgTarget:true,
			layout:'form',
			autoScroll:true,
			items: [{
				name: 'code',
				xtype: 'textfield',
				fieldLabel: GO.timeregistration.lang.code,
				anchor: '100%',
				allowBlank:false
			},{
				name: 'name',
				xtype: 'textfield',
				fieldLabel: GO.timeregistration.lang.name,
				anchor: '100%',
				allowBlank:false
			},{
				name: 'units',
				xtype: 'numberfield',
				fieldLabel: GO.timeregistration.lang.units,
				anchor: '100%',
				allowBlank:false
			},{
				name: 'description',
				xtype: 'textarea',
				fieldLabel: GO.timeregistration.lang.description,
				anchor: '100%',
				allowBlank:true
			}
		]
		});

		var items = [this.standardTaskPanel];

		this.formPanel = new Ext.form.FormPanel({
			waitMsgTarget:true,
			baseParams: {standard_task_id:0},
			url: GO.settings.modules.timeregistration.url+'json.php',
			border: false,			
			items: items
		});
		
	}	
});
