/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @version $Id: StandardTasksGrid.js 15897 2013-05-21 09:02:45Z mschering $
 * @copyright Copyright Intermesh
 * @author Wesley Smits <wsmits@intermesh.nl>
 */
GO.timeregistration.StandardTasksGrid = function(config){

	if(!config)
	{
		config = {};
	}

	config.title = GO.timeregistration.lang.standardTasks;
	config.layout='fit';
	config.autoScroll=true;
	config.split=true;
	config.paging=true,
	config.height=340,
	config.store = new GO.data.JsonStore({
		/*
		 * Here we store our remotely-loaded JSON data from json.php?task=standardTasks
		 */
		url: GO.settings.modules.timeregistration.url+ 'json.php',
		baseParams: {
			task: 'standard_tasks'
		},
		id: 'id',
		root: 'results',
		fields: ['id','code','name','units','description'],
		remoteSort: true
	});

	config.tbar=[{
			iconCls:'btn-add',
			text:GO.timeregistration.lang.addStandardTask,
			handler:function(){
				this.showTaskDialog();
			},
			scope:this
		},{
			iconCls:'btn-delete',
			text:GO.timeregistration.lang.delStandardTask,
			handler:function(){
				this.deleteSelected();
				this.changed=true;	
			},
			scope:this
		}];

	/*
	 * ColumnModel used by our PresidentsGrid
	 */
	var standardTasksColumnModel = new Ext.grid.ColumnModel(
		[{
			header: GO.timeregistration.lang.code,
			dataIndex: 'code',
			width: 120
		},{
			id:'name',
			header: GO.timeregistration.lang.name,
			dataIndex: 'name',
			width: 160
		},{
			header: GO.timeregistration.lang.units,
			dataIndex: 'units',
			width: 80,
			align:'right'
		}]);

	standardTasksColumnModel.defaultSortable= true;
	config.cm=standardTasksColumnModel;
	config.autoExpandColumn='name';

	config.view=new Ext.grid.GridView({
		emptyText: GO.lang['strNoItems']
	});

	config.sm=new Ext.grid.RowSelectionModel();
	config.loadMask=true;

	/*
	 * explicitly call the superclass constructor
	 */
	GO.timeregistration.StandardTasksGrid.superclass.constructor.call(this, config);



	this.on('rowdblclick', function(grid, rowIndex){
		var record = grid.getStore().getAt(rowIndex);

		this.showTaskDialog(record.data.id);

		}, this);
};
/*
 * Extend the base class
 */
Ext.extend(GO.timeregistration.StandardTasksGrid, GO.grid.GridPanel,{

	loaded : false,

	afterRender : function()
	{
		GO.timeregistration.StandardTasksGrid.superclass.afterRender.call(this);
		this.store.load();
	},

	showTaskDialog : function(task_id)
	{
		if(!this.standardTaskDialog)
		{
			this.standardTaskDialog = new GO.timeregistration.StandardTaskDialog({
				listeners:{
					save:function(){
						this.store.reload();
					},
					scope:this
				}
			});
		}
		this.standardTaskDialog.show(task_id);
	}
});

