/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @copyright Copyright Intermesh
 * @version $Id: TimeSheet.js 20824 2015-09-17 08:13:23Z mdhart $
 * @author Merijn Schering <mschering@intermesh.nl>
 */



GO.timeregistration.TimeSheet = function(config) {
	config = config || {};

	config.border=true;
	config.title = GO.projects.lang.timeTracking;
	config.waitMsgTarget = true;
	config.autoScroll = true;
	config.layout='fit';
	config.paging=true;

	config.store = new GO.data.JsonStore({
		url : GO.settings.modules.timeregistration.url + 'json.php',
		baseParams : {
			task : 'timesheet',
			user_id : 0
		},
		root : 'results',
		id : 'id',
		totalProperty : 'total',
		fields : ['project_id', 'fee_id', 'path', 'customer', 'description', 
		'days_0', 'days_1', 'days_2', 'days_3', 'days_4', 'days_5', 'days_6',
		'days_0_approved_at', 'days_1_approved_at', 'days_2_approved_at', 'days_3_approved_at', 
		'days_4_approved_at', 'days_5_approved_at', 'days_6_approved_at',
		'comments_0', 'comments_1', 'comments_2', 'comments_3',
		'comments_4', 'comments_5', 'comments_6', 'due_time',
		'units_booked', 'units_budget', 'bookable', 'timer',
		'tip', 'action', 'hide'],
		remoteSort : true
	});

	config.store.on('beforeload', function(){
		if(this.confirmChanges()){
			this.store.commitChanges();
			return true;
		}else
		{
			return false;
		}
	}, this);

	this.action = new Ext.ux.grid.RowActions({
		id:'timer',
		header : GO.projects.lang.timer,
		autoWidth : false,
		width : 50,
		align : 'center',
		hidden:true,
		actions : [{
			iconCls : 'pm-btn-stop-timer',
			qtip : GO.timeregistration.lang.stopTimer
		}]
	});

	this.action.on({
		action : function(grid, record, action, row, col) {

			var field = 'days_'+new Date().format('w');
			var value = GO.timeregistration.timerButton.stopTimer();
	
			var index = 'days_'+new Date().format('w');
			
			var oldVal= GO.util.unlocalizeNumber(record.get(index));

			record.set(index, GO.util.numberFormat(oldVal+value));
		}
	});

	var columnModel = new Ext.grid.ColumnModel({
		defaults:{
			sortable:false,
			menuDisabled: false
		},
		columns:[{
			header : GO.projects.lang.project,
			dataIndex : 'path',
			width : 220,
			renderer : this.renderProject,
			summaryRenderer : function(){
				return GO.lang.totals+':'
			},
			hideable:true,
			sortable:true
		},{
			header : GO.projects.lang.customer,
			dataIndex : 'customer',
			width : 220,
			hidden:true,
			renderer : this.renderProject,
			sortable:true
		},{
			header : GO.lang.strDescription,
			dataIndex : 'description',
			width : 220
		}, {
			header : GO.projects.lang.fee,
			dataIndex : 'fee_id',
			width : 100,
			editor : new GO.timeregistration.SelectFee({
				width : 140
			}),
			hideable:true,
			renderer : this.renderSelect.createDelegate(this)
		}, {
			id : 'days_1',
			header : GO.lang.shortDays[1],
			dataIndex : 'days_1',
			align : "right",
			width : 65,
			renderer : this.renderDay,
			summaryRenderer : this.renderDay,
			hideable:false,
			editor : new GO.form.NumberField({
				width : 40
			})
		}, {
			id : 'days_2',
			header : GO.lang.shortDays[2],
			dataIndex : 'days_2',
			align : "right",
			width : 65,
			renderer : this.renderDay,
			summaryRenderer : this.renderDay,
			hideable:false,
			editor : new GO.form.NumberField({
				width : 40
			})
		}, {
			id : 'days_3',
			header : GO.lang.shortDays[3],
			dataIndex : 'days_3',
			align : "right",
			width : 65,
			renderer : this.renderDay,
			summaryRenderer : this.renderDay,
			hideable:false,
			editor : new GO.form.NumberField({
				width : 40
			})
		}, {
			id : 'days_4',
			header : GO.lang.shortDays[4],
			dataIndex : 'days_4',
			align : "right",
			width : 65,
			renderer : this.renderDay,
			summaryRenderer : this.renderDay,
			hideable:false,
			editor : new GO.form.NumberField({
				width : 40
			})
		}, {
			header : GO.lang.shortDays[5],
			id : 'days_5',
			dataIndex : 'days_5',
			align : "right",
			width : 65,
			renderer : this.renderDay,
			summaryRenderer : this.renderDay,
			hideable:false,
			editor : new GO.form.NumberField({
				width : 40
			})
		}, {
			id : 'days_6',
			header : GO.lang.shortDays[6],
			dataIndex : 'days_6',
			align : "right",
			width : 65,
			renderer : this.renderDay,
			summaryRenderer : this.renderDay,
			hideable:false,
			editor : new GO.form.NumberField({
				width : 40
			})
		}, {
			id : 'days_0',
			header : GO.lang.shortDays[0],
			dataIndex : 'days_0',
			align : "right",
			width : 65,
			renderer : this.renderDay,
			summaryRenderer : this.renderDay,
			hideable:false,
			editor : new GO.form.NumberField({
				width : 40
			})
		}, {
			header : GO.lang.strWeek,
			dataIndex : 'week_total',
			align : "right",
			renderer : function(value, cell, record) {
				return '<span id="week_total_id_' + record.id + '"></span>';
			},
			width : 50
		}, this.action]
	});

	/*this.wp = new GO.WeekPicker();
	this.wp.on('beforechange', function(){
		return this.confirmChanges();
	}, this);
	this.wp.on('change', function(wp, newDate, oldDate){
		this.store.commitChanges();
		this.store.baseParams.date = this.wp.getDate().format(GO.settings.date_format);

		this.store.load();

		for (var day = 1; day < 8; day++) {
			var displayDay = newDate.add(Date.DAY, day).format('j');
			var shortDay = (day != 7) ? day : 0;

			var col_index = this.getColumnModel().getIndexById(day + 2);
			this.getColumnModel().setColumnHeader(
					col_index,
					GO.lang.shortDays[shortDay] + " (" + displayDay
							+ ")");
		}
	}, this);*/

	config.loadMask = true;
	config.clicksToEdit = 1;
	//config.enableColumnMove = false;

	
	config.cm = columnModel;
	config.plugins = [this.action, new GO.grid.RemoteGridTotals()];
	config.view = new Ext.grid.GridView({
		emptyText : GO.lang['strNoItems']
	});
	config.sm = new Ext.grid.RowSelectionModel();

	config.sm.orgOnEditorKey = config.sm.onEditorKey;
	config.sm.onEditorKey=function(field, e) {
		if(!config.commentsPanel.isVisible()){
			config.sm.orgOnEditorKey.call(config.sm, field, e);
		}
	};

	config.commentsPanel.commentsField.on('specialkey', this.nextComment, this);

	GO.timeregistration.TimeSheet.superclass.constructor.call(this, config);

	this.addEvents({
		editcomplete : true
	});

	this.on('beforeedit', this.beforeEdit, this);
	this.on('editcomplete', function(ed) {
		this.currentEditor = ed;

		var cm = this.getColumnModel();
		var col_id = cm.getColumnId(ed.col);
		if (col_id.substring(0,5) =='days_') {

			if(!this.commentsPanel.isVisible()){
			//this.nextComment();
	
			}else
			{
				if (Ext.isIE) {
					this.commentsPanel.commentsField.focus(false, 50);
				} else {
					this.commentsPanel.commentsField.focus();
				}
			}
			ed.record.set(col_id,this.roundTime(ed.record.data[col_id]));
			this.updateTotals(true);
		}
	}, this);

	config.store.on('load', function() {
		this.timer_running = config.store.reader.jsonData.timer_running;

		this.hours_booked=config.store.reader.jsonData.totals.hours_booked;

		this.commentsPanel.commentsField.setDisabled(true);
		if (config.store.data.items.length) {
			this.updateTotals();
		}
	}, this);
}

Ext.extend(GO.timeregistration.TimeSheet, GO.grid.EditorGridPanel, {
	currentEditor : false,

	hours_booked : 0,

	commentsPanel : false,

	roundTime : function(value) {
		value = GO.util.unlocalizeNumber(value);
		value = GO.util.round(value*60, GO.timeregistration.roundMinutes, !GO.timeregistration.roundUp);
		value = value/60;
		return GO.util.numberFormat(value, this.decimals);
	},

	nextComment : function(field, e) {
		var ed = this.currentEditor;
		if (ed.col > 1) {
			var k = e.getKey();
			var shift = e.shiftKey;
			if (k == e.TAB) {

				this.commentsPanel.record.set(
					this.commentsPanel.name,
					this.commentsPanel.commentsField.getValue());

				e.preventDefault();
				var sm = this.getSelectionModel();
				if (shift) {
					var newCell = this.walkCells(ed.row, ed.col - 1,
						-1, sm.acceptsNav, sm);
				} else {
					var newCell = this.walkCells(ed.row, ed.col + 1, 1,
						sm.acceptsNav, sm);
				}

				if (newCell) {
					this.startEditing(newCell[0], newCell[1]);
				}
			}
		}
	},

	onEditComplete : function(ed, value, startValue) {
		this.editing = false;
		this.activeEditor = null;
		ed.un("specialkey", this.selModel.onEditorKey, this.selModel);
		var r = ed.record;
		var field = this.colModel.getDataIndex(ed.col);
		value = this.postEditValue(value, startValue, r, field);
		if (String(value) !== String(startValue)) {
			var e = {
				grid : this,
				record : r,
				field : field,
				originalValue : startValue,
				value : value,
				row : ed.row,
				column : ed.col,
				cancel : false
			};
			if (this.fireEvent("validateedit", e) !== false
				&& !e.cancel) {
				r.set(field, e.value);
				delete e.cancel;
				this.fireEvent("afteredit", e);
			}
		}

		this.fireEvent('editcomplete', ed);
	},

	beforeEdit : function(e) {
		var bookable = e.record.get('bookable') && e.record.get(e.field+'_approved_at')=='';
		if (!bookable) {
			return false;
		}
		if (e.field.substring(0, 4) == 'days') {

			if(e.record.get('status_'+e.field)=="1")
			{
				//hours have been approved and may not be edited
				return false;
			}

			var day = e.field.substring(5, 6);
      
			if (e.field.substring(0, 4) == 'days') {
				var day = e.field.substring(5, 6);

				var cm = this.getColumnModel();
				var ce = cm.getCellEditor(e.column, e.row);

				this.commentsPanel.setTitle(GO.lang.strDescription + ' ('
					+ GO.lang.shortDays[day] + ')');
				this.commentsPanel.setField('comments_' + day, e.record);
			}
		}
	},


	renderSelect : function(value, p, record, rowIndex, colIndex, ds) {
		var cm = this.getColumnModel();
		var ce = cm.getCellEditor(colIndex, rowIndex);

		var val = '';
		if (ce.field.store.getById(value) !== undefined) {
			val = ce.field.store.getById(value).get("name");
		}
		return val;
	},

	renderDay : function(v, p, record, rowIndex, colIndex, ds) {
		if(!record.json){
			return '<br />'+v;
		}
		if(record.data && record.data[p.id+'_approved_at']){
			p.css='pm-disabled-cell';
			p.attr='ext:qtip="'+GO.projects.lang.hoursAlreadyApproved+'<br> '+record.data[p.id+'_approved_at']+'"';
		}
		return v;
		
	},

	renderProject : function(v, p, record, rowIndex, colIndex, ds) {

		if (record.data.units_budget > 0
			&& record.data.units_budget < record.data.units_booked) {
			v = '<div class="timeregistration-late" ext:qtip="'
			+ GO.projects.lang.budgetReached + '">' + v
			+ '</div>';
		} else if (record.data.due_time != '') {
			var now = new Date();
			var date = Date.parseDate(record.data.due_time,
				GO.settings.date_format);

			if (date < now) {
				v = '<div class="timeregistration-late" ext:qtip="'
				+ GO.projects.lang.projectEnded + '">' + v
				+ '</div>';
			}
		}

		return v;
	},

	getGridData : function() {

		var keys=[
		'project_id',
		'fee_id',
		'days_0',
		'days_1',
		'days_2',
		'days_3',
		'days_4',
		'days_5',
		'days_6',
		'comments_0',
		'comments_1',
		'comments_2',
		'comments_3',
		'comments_4',
		'comments_5',
		'comments_6'
		];

		var data = {};
		for (var i = 0; i < this.store.data.items.length; i++) {
			var r = this.store.data.items[i].data;

			if(!GO.util.empty(r.project_id)){
				data[i] = {};

				for (var key in r) {
					if(keys.indexOf(key)>-1)
						data[i][key] = r[key];
				}
			}
		}
		return data;
	},

	setDate : function(date){

		if (!date) {
			var now = new Date();
			date = now.getLastSunday();
			date = date.add(Date.DAY,parseInt(GO.settings.first_weekday));
		}

		//var firstWeekDay = date.add(Date.DAY,parseInt(GO.settings.first_weekday));
		this.setTitle(GO.lang.strWeek+' '+date.format('W')+' ('+date.format(GO.settings.date_format)+')');

		this.store.commitChanges();
		this.store.baseParams.date = date.format(GO.settings.date_format);

		var cm = this.getColumnModel();
		for (var day = 1; day < 8; day++) {
			var displayDay = date.add(Date.DAY, day-1).format('j');
			var shortDay = (day != 7) ? day : 0;
			var col_index = this.getColumnModel().getIndexById('days_'+shortDay);
			cm.setColumnHeader(
				col_index,
				GO.lang.shortDays[shortDay] + " (" + displayDay
				+ ")");
		}
		
		this.store.load();
	},

	confirmChanges : function() {
		return (!this.isDirty() || confirm(GO.lang.changesWillBeLost));
	},

	isDirty : function(){
		var mods = this.store.getModifiedRecords();
		return mods.length>0;
	},

	save : function(config, deferred){

		if(!deferred)
			this.el.mask(GO.lang.waitMsgSave);

		//IE is so slow it might be still exiting the edit mode in the grid
		if(this.editing){
			this.save.defer(100,this,[config, true]);
			return;
		}
		config = config || {};
		
		if(this.store.lastOptions.params)
			delete this.store.lastOptions.params.save_data;
		
		this.store.baseParams.save_data=Ext.encode(this.getGridData()),

		this.store.commitChanges();

		this.store.reload({
			scope:this,
			callback:function(){
				if(config.callback)
					config.callback.call(config.scope);
				this.el.unmask();
			}
		});
		delete this.store.baseParams.save_data;
	},
	
	updateTotals : function(remove_totals_row) {
		/*if (remove_totals_row) {
			this.store.removeAt(this.store.data.items.length - 1);
		}*/

		var rows = {};
		var columns = {};
		columns[0] = 0;
		columns[1] = 0;
		columns[2] = 0;
		columns[3] = 0;
		columns[4] = 0;
		columns[5] = 0;
		columns[6] = 0;
		columns[7] = 0;
		// count totals
		for (var i = 0; i < this.store.data.items.length; i++) {
			var r = this.store.data.items[i].data;
			var sum_rows = 0;
			for (var j = 0; j < 7; j++) {
				var num = GO.util.unlocalizeNumber(r['days_' + j]);
				sum_rows += num;
				columns[j] += num;
			}
			rows[i] = sum_rows;
			columns[7] += sum_rows;
		}

		//if (!remove_totals_row) {
		//this.hours_booked = columns[7];
		//}

		/*
		// create new record (day totals)
		var values = {};
		values['name'] = '<br />' + GO.projects.lang.total;
		values['hide'] = true;
		values['totals']=true;

		var numb;

		for (var j = 0; j < 7; j++) {
			numb = GO.util.numberFormat('' + columns[j]);
			values['days_' + j] = numb;
		}

		// add record to store
		var record = new Ext.data.Record(values);
		this.store.add(record);*/

		// update columns (week totals)
		for (var i = 0; i < this.store.data.items.length; i++) {
			var id = this.store.getAt(i).id;
			var el = Ext.get('week_total_id_' + id);

			//if (i < this.store.data.items.length - 1) {
			if(el)
			el.update(GO.util.numberFormat('' + rows[i]));
		/*} else {
				el.update('<br />'
						+ GO.util.numberFormat('' + columns[7]));
			}*/
		}
	}

});
