/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @version $Id: addTimeRegistrationDialog.js 15897 2013-05-21 09:02:45Z mschering $
 * @copyright Copyright Intermesh
 * @author Wesley Smits <wsmits@intermesh.nl>
 */
GO.timeregistration.addTimeRegistrationDialog = function(config){

	if(!config)
	{
		config={};
	}

	this.buildForm();

	var focusFirstField = function(){
		this.addTimeRegistrationPanel.items.items[0].focus();
	};

	config.maximizable=true;
	config.layout='fit';
	config.modal=false;
	config.resizable=false;
	config.width=300;
	config.height=172;
	config.closeAction='hide';
	config.title= GO.projects.lang.timeTracking;
	config.items= this.formPanel;
	config.focus= focusFirstField.createDelegate(this);
	config.buttons=[{
			text: GO.lang['cmdOk'],
			handler: function(){
				this.submitForm(true);
			},
			scope: this
		},{
			text: GO.lang['cmdClose'],
			handler: function(){
				this.hide();
			},
			scope:this
		}
	];

	/*
	 * explicitly call the superclass constructor
	 */
	GO.timeregistration.addTimeRegistrationDialog.superclass.constructor.call(this, config);

	this.addEvents({'save' : true});

}


/*
 * Extend the base class
 */
Ext.extend(GO.timeregistration.addTimeRegistrationDialog, GO.Window,{

	event:0,

	show : function (event){

		if(!this.rendered)
			this.render(Ext.getBody());

		this.event = event;
		GO.timeregistration.addTimeRegistrationDialog.superclass.show.call(this);
	},

	submitForm : function(hide){

		var startTime = Date.parseDate(this.event.start_time, 'Y-m-d H:i');
		var endTime = Date.parseDate(this.event.end_time, 'Y-m-d H:i');
		var duration = startTime.getElapsed(endTime)/3600000;

		duration = GO.util.numberFormat(duration);

		this.formPanel.form.submit(
		{
			url:GO.settings.modules.timeregistration.url+'action.php',
			params: {
				'task' : 'save_hours',
				'units' : duration,
				'add_from_calendar' : true,
				'date' : this.event.start_time,
				'fee_id' : 0
			},
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action){
				this.fireEvent('save', this);

				if(hide)
				{
					this.hide();
				}
			},
			failure: function(form, action) {
				if(action.failureType == 'client')
				{
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope: this
		});
	},

	buildForm : function () {

		this.selectProject = new GO.timeregistration.SelectProject({
			allowBlank:false,
			anchor:'100%'
		});

		this.addTimeRegistrationPanel = new Ext.Panel({
			border: false,
			cls:'go-form-panel',waitMsgTarget:true,
			layout:'form',
			autoScroll:true,
			items: [
				this.selectProject,{
				name: 'comments',
				xtype: 'textarea',
				fieldLabel: GO.timeregistration.lang.description,
				anchor: '100%',
				allowBlank:true
			}
		]
		});

		var items = [this.addTimeRegistrationPanel];

		this.formPanel = new Ext.form.FormPanel({
			waitMsgTarget:true,
			border: false,
			items: items
		});

	}
});
